@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -33,6 +33,7 @@
 #include <list>
 #include <sstream>
 #include <stdio.h>
+#include <cstring>
 
 namespace tnt
 {
@@ -42,8 +43,8 @@ namespace tnt
   void HttpMessage::clear()
   {
     header.clear();
-    majorVersion = 1;
-    minorVersion = 0;
+    _majorVersion = 1;
+    _minorVersion = 0;
   }
 
   const char* HttpMessage::getHeader(const char* key, const char* def) const
@@ -70,28 +71,51 @@ namespace tnt
   {
     struct ::tm tm;
     gmtime_r(&t, &tm);
-    return htdate(&tm);
+
+    char date[30];
+    htdate(date, t);
+
+    return date;
   }
 
-  std::string HttpMessage::htdate(struct ::tm* tm)
+  void HttpMessage::htdate(char* date, time_t t)
+  {
+    struct ::tm tm;
+    gmtime_r(&t, &tm);
+    htdate(date, &tm);
+  }
+
+  std::string HttpMessage::htdate(const struct ::tm* tm)
+  {
+    char date[30];
+    htdate(date, tm);
+    return date;
+  }
+
+  void HttpMessage::htdate(char* date, const struct ::tm* tm)
   {
     static const char* wday[] = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"};
     static const char* monthn[] = {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
                             "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"};
-    char buffer[80];
 
-    sprintf(buffer, "%s, %02d %s %d %02d:%02d:%02d GMT",
+    sprintf(date, "%s, %02d %s %d %02d:%02d:%02d GMT",
       wday[tm->tm_wday], tm->tm_mday, monthn[tm->tm_mon], tm->tm_year + 1900,
       tm->tm_hour, tm->tm_min, tm->tm_sec);
-    return buffer;
   }
 
   std::string HttpMessage::htdateCurrent()
+  {
+    char current[30];
+    htdateCurrent(current);
+    return current;
+  }
+
+  void HttpMessage::htdateCurrent(char* current)
   {
     static struct ::tm lastTm;
     static time_t lastDay = 0;
     static time_t lastTime = 0;
-    static std::string lastHtdate;
+    static char lastHtdate[30];
     static cxxtools::Mutex mutex;
 
     /*
@@ -119,53 +143,49 @@ namespace tnt
       lastTm.tm_min = t % 60;
       t /= 60;
       lastTm.tm_hour = t % 24;
-      lastHtdate = htdate(&lastTm);
+      htdate(lastHtdate, &lastTm);
       lastTime = t;
     }
 
     // we do a copy of lastHtdate first to make sure we have the lock
-    std::string ret = lastHtdate;
-    return ret;
+    std::strcpy(current, lastHtdate);
   }
 
   namespace
   {
     class Pstr
     {
-        const char* start;
-        const char* end;
+      private:
+        const char* _start;
+        const char* _end;
 
       public:
         typedef size_t size_type;
 
         Pstr(const char* s, const char* e)
-          : start(s), end(e)
+          : _start(s), _end(e)
           { }
 
         void setStart(const char* s)
-        {
-          start = s;
-        }
+          { _start = s; }
 
         void setEnd(const char* e)
-        {
-          end = e;
-        }
+          { _end = e; }
 
-        size_type size() const  { return end - start; }
-        bool empty() const      { return start == end; }
+        size_type size() const { return _end - _start; }
+        bool empty() const     { return _start == _end; }
 
         bool operator== (const Pstr& s) const
         {
           return size() == s.size()
-            && std::equal(start, end, s.start);
+            && std::equal(_start, _end, s._start);
         }
 
         bool operator== (const char* str) const
         {
           size_type i;
           for (i = 0; i < size() && str[i] != '\0'; ++i)
-            if (start[i] != str[i])
+            if (_start[i] != str[i])
               return false;
           return i == size() && str[i] == '\0';
         }
@@ -205,5 +225,5 @@ namespace tnt
 
     return true;
   }
-
 }
+
