@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -35,7 +35,7 @@
 #include <sstream>
 #include <algorithm>
 
-#define SET_STATE(new_state)  state = &Parser::new_state
+#define SET_STATE(new_state) _state = &Parser::new_state
 
 namespace tnt
 {
@@ -59,8 +59,8 @@ namespace tnt
     inline bool isHexDigit(char ch)
     {
       return (ch >= '0' && ch <= '9')
-          || (ch >= 'A' && ch <= 'Z')
-          || (ch >= 'a' && ch <= 'z');
+          || (ch >= 'A' && ch <= 'F')
+          || (ch >= 'a' && ch <= 'f');
     }
 
     inline unsigned valueOfHexDigit(char ch)
@@ -76,7 +76,7 @@ namespace tnt
 
   bool RequestSizeMonitor::post(bool ret)
   {
-    if (++requestSize > TntConfig::it().maxRequestSize
+    if (++_requestSize > TntConfig::it().maxRequestSize
       && TntConfig::it().maxRequestSize > 0)
     {
       requestSizeExceeded();
@@ -86,59 +86,59 @@ namespace tnt
   }
 
   void RequestSizeMonitor::requestSizeExceeded()
-  { }
+    { }
 
   void HttpRequest::Parser::reset()
   {
-    message.clear();
+    _message.clear();
     SET_STATE(state_cmd0);
-    httpCode = HTTP_OK;
-    failedFlag = false;
+    _httpCode = HTTP_OK;
+    _failedFlag = false;
     RequestSizeMonitor::reset();
-    headerParser.reset();
+    _headerParser.reset();
   }
 
   bool HttpRequest::Parser::state_cmd0(char ch)
   {
     if (istokenchar(ch))
     {
-      message.method[0] = ch;
-      message.methodLen = 1;
+      _message._method[0] = ch;
+      _message._methodLen = 1;
       SET_STATE(state_cmd);
     }
     else if (ch != ' ' && ch != '\t')
     {
       log_warn("invalid character " << chartoprint(ch) << " in method");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_cmd(char ch)
   {
     if (istokenchar(ch))
     {
-      if (message.methodLen >= sizeof(message.method) - 1)
+      if (_message._methodLen >= sizeof(_message._method) - 1)
       {
-        log_debug("invalid method field; method=" << std::string(message.method, message.methodLen) << ", len=" << message.methodLen);
+        log_debug("invalid method field; method=" << std::string(_message._method, _message._methodLen) << ", len=" << _message._methodLen);
         throw HttpError(HTTP_BAD_REQUEST, "invalid method field");
       }
-      message.method[message.methodLen++] = ch;
+      _message._method[_message._methodLen++] = ch;
     }
     else if (ch == ' ')
     {
-      message.method[message.methodLen] = '\0';
-      log_debug("method=" << message.method);
+      _message._method[_message._methodLen] = '\0';
+      log_debug("method=" << _message._method);
       SET_STATE(state_url0);
     }
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in method");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_url0(char ch)
@@ -148,9 +148,9 @@ namespace tnt
     }
     else if (ch == '/')
     {
-      message.url.clear();
-      message.url.reserve(32);
-      message.url += ch;
+      _message._url.clear();
+      _message._url.reserve(32);
+      _message._url += ch;
       SET_STATE(state_url);
     }
     else if (std::isalpha(ch))
@@ -160,11 +160,11 @@ namespace tnt
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in url");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
 
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_protocol(char ch)
@@ -174,11 +174,11 @@ namespace tnt
     else if (!std::isalpha(ch))
     {
       log_warn("invalid character " << chartoprint(ch) << " in url");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
 
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_protocol_slash1(char ch)
@@ -188,11 +188,11 @@ namespace tnt
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in url");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
 
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_protocol_slash2(char ch)
@@ -202,20 +202,20 @@ namespace tnt
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in url");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
 
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_protocol_host(char ch)
   {
     if (ch == '/')
     {
-      message.url.clear();
-      message.url.reserve(32);
-      message.url += ch;
+      _message._url.clear();
+      _message._url.reserve(32);
+      _message._url += ch;
       SET_STATE(state_url);
     }
     else if (!std::isalpha(ch)
@@ -226,65 +226,67 @@ namespace tnt
            && ch != ':')
     {
       log_warn("invalid character " << chartoprint(ch) << " in url");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
 
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_url(char ch)
   {
     if (ch == '?')
     {
-      log_debug("url=" << message.url);
+      log_debug("url=" << _message._url);
       SET_STATE(state_qparam);
     }
     else if (ch == '\r')
     {
-      log_debug("url=" << message.url);
+      log_debug("url=" << _message._url);
       SET_STATE(state_end0);
     }
     else if (ch == '\n')
     {
-      log_debug("url=" << message.url);
+      log_debug("url=" << _message._url);
       SET_STATE(state_header);
     }
     else if (ch == ' ' || ch == '\t')
     {
-      log_debug("url=" << message.url);
+      log_debug("url=" << _message._url);
       SET_STATE(state_version);
     }
     else if (ch == '%')
     {
       SET_STATE(state_urlesc);
-      message.url += ch;
+      _message._url += ch;
     }
     else if (ch > ' ')
-      message.url += ch;
+      _message._url += ch;
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in url");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_urlesc(char ch)
   {
     if (isHexDigit(ch))
     {
-      if (message.url.size() >= 2 && message.url[message.url.size() - 2] == '%')
+      if (_message._url.size() >= 2 && _message._url[_message._url.size() - 2] == '%')
       {
-        unsigned v = (valueOfHexDigit(message.url[message.url.size() - 1]) << 4) | valueOfHexDigit(ch);
-        message.url[message.url.size() - 2] = static_cast<char>(v);
-        message.url.resize(message.url.size() - 1);
+        unsigned v = (valueOfHexDigit(_message._url[_message._url.size() - 1]) << 4) | valueOfHexDigit(ch);
+        if (v == 0)
+          throw HttpError(HTTP_BAD_REQUEST, "invalid value in url");
+        _message._url[_message._url.size() - 2] = static_cast<char>(v);
+        _message._url.resize(_message._url.size() - 1);
         SET_STATE(state_url);
       }
       else
       {
-        message.url += ch;
+        _message._url += ch;
       }
       return false;
     }
@@ -299,11 +301,11 @@ namespace tnt
   {
     if (ch == ' ' || ch == '\t')
     {
-      log_debug("queryString=" << message.queryString);
+      log_debug("queryString=" << _message._queryString);
       SET_STATE(state_version);
     }
     else
-      message.queryString += ch;
+      _message._queryString += ch;
     return false;
   }
 
@@ -311,16 +313,16 @@ namespace tnt
   {
     if (ch == '/')
     {
-      message.setVersion(0, 0);
+      _message.setVersion(0, 0);
       skipWs(&Parser::state_version_major);
     }
     else if (ch == '\r')
     {
       log_warn("invalid character " << chartoprint(ch) << " in version");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_version_major(char ch)
@@ -328,16 +330,16 @@ namespace tnt
     if (ch == '.')
       SET_STATE(state_version_minor0);
     else if (std::isdigit(ch))
-      message.setVersion(message.getMajorVersion() * 10 + (ch - '0'), message.getMinorVersion());
+      _message.setVersion(_message.getMajorVersion() * 10 + (ch - '0'), _message.getMinorVersion());
     else if (ch == ' ' || ch == '\t')
       SET_STATE(state_version_major_sp);
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in version-major");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_version_major_sp(char ch)
@@ -347,15 +349,15 @@ namespace tnt
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in version-major");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_version_minor0(char ch)
   {
-    return ch == ' ' || ch == '\t' ? failedFlag
+    return ch == ' ' || ch == '\t' ? _failedFlag
                                    : state_version_minor(ch);
   }
 
@@ -366,14 +368,14 @@ namespace tnt
     else if (ch == ' ' || ch == '\t' || ch == '\r')
       SET_STATE(state_end0);
     else if (std::isdigit(ch))
-      message.setVersion(message.getMajorVersion(), message.getMinorVersion() * 10 + (ch - '0'));
+      _message.setVersion(_message.getMajorVersion(), _message.getMinorVersion() * 10 + (ch - '0'));
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in version-minor");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_end0(char ch)
@@ -383,48 +385,48 @@ namespace tnt
     else if (ch != ' ' && ch != '\t')
     {
       log_warn("invalid character " << chartoprint(ch) << " in end");
-      httpCode = HTTP_BAD_REQUEST;
-      failedFlag = true;
+      _httpCode = HTTP_BAD_REQUEST;
+      _failedFlag = true;
     }
-    return failedFlag;
+    return _failedFlag;
   }
 
   bool HttpRequest::Parser::state_header(char ch)
   {
-    if (headerParser.parse(ch))
+    if (_headerParser.parse(ch))
     {
-      if (headerParser.failed())
+      if (_headerParser.failed())
       {
-        httpCode = HTTP_BAD_REQUEST;
-        failedFlag = true;
+        _httpCode = HTTP_BAD_REQUEST;
+        _failedFlag = true;
         return true;
       }
 
-      const char* content_length_header = message.getHeader(httpheader::contentLength);
+      const char* content_length_header = _message.getHeader(httpheader::contentLength);
       if (*content_length_header)
       {
-        bodySize = 0;
+        _bodySize = 0;
         for (const char* c = content_length_header; *c; ++c)
         {
           if (*c > '9' || *c < '0')
             throw HttpError(HTTP_BAD_REQUEST, "invalid Content-Length");
-          bodySize = bodySize * 10 + *c - '0';
+          _bodySize = _bodySize * 10 + *c - '0';
         }
 
         if (TntConfig::it().maxRequestSize > 0
-          && getCurrentRequestSize() + bodySize > TntConfig::it().maxRequestSize)
+          && getCurrentRequestSize() + _bodySize > TntConfig::it().maxRequestSize)
         {
           requestSizeExceeded();
           return true;
         }
 
-        message.contentSize = bodySize;
-        if (bodySize == 0)
+        _message._contentSize = _bodySize;
+        if (_bodySize == 0)
           return true;
         else
         {
           SET_STATE(state_body);
-          message.body.reserve(bodySize);
+          _message._body.reserve(_bodySize);
           return false;
         }
       }
@@ -437,14 +439,15 @@ namespace tnt
 
   bool HttpRequest::Parser::state_body(char ch)
   {
-    message.body += ch;
-    return --bodySize == 0;
+    _message._body += ch;
+    return --_bodySize == 0;
   }
 
   void HttpRequest::Parser::requestSizeExceeded()
   {
     log_warn("max request size " << TntConfig::it().maxRequestSize << " exceeded");
-    httpCode = HTTP_REQUEST_ENTITY_TOO_LARGE;
-    failedFlag = true;
+    _httpCode = HTTP_REQUEST_ENTITY_TOO_LARGE;
+    _failedFlag = true;
   }
 }
+
