@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -33,14 +33,7 @@
 #include <cxxtools/log.h>
 #include <cxxtools/net/net.h>
 #include <unistd.h>
-
-#ifdef WITH_GNUTLS
-#  include "tnt/gnutls.h"
-#endif
-
-#ifdef WITH_OPENSSL
-#  include "tnt/openssl.h"
-#endif
+#include "config.h"
 
 log_define("tntnet.listener")
 
@@ -49,14 +42,22 @@ namespace tnt
   namespace
   {
     void doListenRetry(cxxtools::net::TcpServer& server,
-      const char* ipaddr, unsigned short int port)
+      const std::string& ipaddr, unsigned short int port)
     {
       for (unsigned n = 1; true; ++n)
       {
         try
         {
           log_debug("listen " << ipaddr << ':' << port);
+#ifdef HAVE_CXXTOOLS_REUSEADDR
+          int flags = cxxtools::net::TcpServer::DEFER_ACCEPT;
+          if (TntConfig::it().reuseAddress)
+            flags |= cxxtools::net::TcpServer::REUSEADDR;
+
+          server.listen(ipaddr, port, TntConfig::it().listenBacklog, flags);
+#else
           server.listen(ipaddr, port, TntConfig::it().listenBacklog, cxxtools::net::TcpServer::DEFER_ACCEPT);
+#endif
           return;
         }
         catch (const cxxtools::net::AddressInUse& e)
@@ -74,69 +75,27 @@ namespace tnt
     }
   }
 
-  void ListenerBase::terminate()
+  Listener::Listener(Tntnet& application, const std::string& ipaddr, unsigned short int port, Jobqueue& q,
+    const std::string& certificateFile, const std::string& privateKeyFile,
+    int sslVerifyLevel, const std::string& sslCa)
+    : _queue(q),
+      _certificateFile(certificateFile),
+      _privateKeyFile(privateKeyFile),
+      _sslVerifyLevel(sslVerifyLevel),
+      _sslCa(sslCa)
   {
-    log_info("stop listener " << ipaddr << ':' << port);
-    doTerminate();
+    log_info("listen ip=" << ipaddr << " port=" << port);
+    doListenRetry(_server, ipaddr, port);
+    Jobqueue::JobPtr p = new Tcpjob(application, _server, _queue,
+                                    certificateFile, privateKeyFile,
+                                    sslVerifyLevel, sslCa);
+    _queue.put(p);
   }
 
-  void ListenerBase::initialize()
+  void Listener::terminate()
   {
+    log_info("stop listener");
+    _server.terminateAccept();
   }
 
-  Listener::Listener(Tntnet& application, const std::string& ipaddr_, unsigned short int port_, Jobqueue& q)
-    : ListenerBase(ipaddr_, port_),
-      queue(q)
-  {
-    doListenRetry(server, ipaddr_.c_str(), port_);
-    Jobqueue::JobPtr p = new Tcpjob(application, server, queue);
-    queue.put(p);
-  }
-
-  void Listener::doTerminate()
-  {
-    server.terminateAccept();
-  }
-
-  void Listener::initialize()
-  {
-    log_info("listen ip=" << getIpaddr() << " port=" << getPort());
-  }
-
-#ifdef WITH_GNUTLS
-#define USE_SSL
-
-#endif
-
-#ifdef WITH_OPENSSL
-#define USE_SSL
-
-#endif
-
-#ifdef USE_SSL
-  Ssllistener::Ssllistener(Tntnet& application, const char* certificateFile,
-      const char* keyFile,
-      const std::string& ipaddr_, unsigned short int port_,
-      Jobqueue& q)
-    : ListenerBase(ipaddr_, port_),
-      server(certificateFile, keyFile),
-      queue(q)
-  {
-    doListenRetry(server, ipaddr_.c_str(), port_);
-    Jobqueue::JobPtr p = new SslTcpjob(application, server, queue);
-    queue.put(p);
-  }
-
-  void Ssllistener::doTerminate()
-  {
-    server.terminateAccept();
-  }
-
-  void Ssllistener::initialize()
-  {
-    log_info("listen ip=" << getIpaddr() << " port=" << getPort() << " (ssl)");
-  }
-
-#endif // USE_SSL
-
 }
