@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -44,8 +44,7 @@ namespace tnt
   {
     const_iterator it = find(key);
     return it == end() ? false
-                       : tnt::StringCompareIgnoreCase<const char*>(
-                           it->second, value) == 0;
+                       : tnt::StringCompareIgnoreCase<const char*>(it->second, value) == 0;
   }
 
   void Messageheader::removeHeader(const char* key)
@@ -62,7 +61,7 @@ namespace tnt
       {
         unsigned slen = it->second - it->first + std::strlen(it->second) + 1;
 
-        std::memcpy(
+        std::memmove(
             const_cast<char*>(it->first),
             it->first + slen,
             p - it->first + slen);
@@ -75,7 +74,7 @@ namespace tnt
         ++it;
     }
 
-    endOffset = p - rawdata;
+    _endOffset = p - _rawdata;
   }
 
   Messageheader::const_iterator Messageheader::find(const char* key) const
@@ -92,10 +91,10 @@ namespace tnt
   void Messageheader::clear()
   {
 #ifdef DEBUG
-    std::memset(rawdata, '\xfe', sizeof(rawdata));
+    std::memset(_rawdata, '\xfe', sizeof(_rawdata));
 #endif
-    rawdata[0] = rawdata[1] = '\0';
-    endOffset = 0;
+    _rawdata[0] = _rawdata[1] = '\0';
+    _endOffset = 0;
   }
 
   void Messageheader::setHeader(const char* key, const char* value, bool replace)
@@ -109,10 +108,10 @@ namespace tnt
     char* p = getEnd();
 
     size_t lk = std::strlen(key);     // length of key
-    size_t lk2 = key[lk-1] == ':' ? lk + 1 : lk;  // length of key including trailing ':'
+    size_t lk2 = key[lk-1] == ':' ? lk + 1 : lk + 2;  // length of key including trailing ':' and terminator
     size_t lv = std::strlen(value);   // length of value
 
-    if (p - rawdata + lk2 + lv + 3 > MAXHEADERSIZE)
+    if (p - _rawdata + lk2 + lv + 3 > MAXHEADERSIZE)
       throw std::runtime_error("message header too big");
 
     std::strcpy(p, key);   // copy key
@@ -122,7 +121,7 @@ namespace tnt
     std::strcpy(p, value); // copy value
     p[lv + 1] = '\0';      // put new message end marker in place
 
-    endOffset = (p + lv + 1) - rawdata;
+    _endOffset = (p + lv + 1) - _rawdata;
   }
 
   Messageheader::return_type Messageheader::onField(const char* name, const char* value)
@@ -137,5 +136,4 @@ namespace tnt
     p.parse(in);
     return in;
   }
-
 }
