@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -49,15 +49,15 @@ namespace tnt
 
   log_define("tntnet.messageheader.parser")
 
-  #define SET_STATE(new_state)  state = &Parser::new_state
+  #define SET_STATE(new_state) _state = &Parser::new_state
 
   bool Messageheader::Parser::state_0(char ch)
   {
     if (ch >= 33 && ch <= 126 && ch != ':')
     {
-      fieldnamePtr = headerdataPtr;
+      _fieldnamePtr = _headerdataPtr;
       checkHeaderspace(1);
-      *headerdataPtr++ = ch;
+      *_headerdataPtr++ = ch;
       SET_STATE(state_fieldname);
     }
     else if (ch == '\n')
@@ -67,7 +67,7 @@ namespace tnt
     else if (!std::isspace(ch))
     {
       log_warn("invalid character " << chartoprint(ch));
-      failedFlag = true;
+      _failedFlag = true;
       return true;
     }
 
@@ -79,7 +79,7 @@ namespace tnt
     if (ch != '\n')
     {
       log_warn("invalid character " << chartoprint(ch) << " in state-cr");
-      failedFlag = true;
+      _failedFlag = true;
     }
     return true;
   }
@@ -89,28 +89,28 @@ namespace tnt
     if (ch == ':')            // Field-name:
     {
       checkHeaderspace(2);
-      *headerdataPtr++ = ch;
-      *headerdataPtr++ = '\0';
-      fieldbodyPtr = headerdataPtr;
+      *_headerdataPtr++ = ch;
+      *_headerdataPtr++ = '\0';
+      _fieldbodyPtr = _headerdataPtr;
       SET_STATE(state_fieldbody0);
     }
     else if (ch >= 33 && ch <= 126)
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = ch;
+      *_headerdataPtr++ = ch;
     }
     else if (std::isspace(ch))
     {
       checkHeaderspace(2);
-      *headerdataPtr++ = ':';
-      *headerdataPtr++ = '\0';
-      fieldbodyPtr = headerdataPtr;
+      *_headerdataPtr++ = ':';
+      *_headerdataPtr++ = '\0';
+      _fieldbodyPtr = _headerdataPtr;
       SET_STATE(state_fieldnamespace);
     }
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in fieldname");
-      failedFlag = true;
+      _failedFlag = true;
       return true;
     }
     return false;
@@ -123,7 +123,7 @@ namespace tnt
     else if (!std::isspace(ch))
     {
       log_warn("invalid character " << chartoprint(ch) << " in fieldname-space");
-      failedFlag = true;
+      _failedFlag = true;
       return true;
     }
     return false;
@@ -134,19 +134,19 @@ namespace tnt
     if (ch == '\r')
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = '\0';
+      *_headerdataPtr++ = '\0';
       SET_STATE(state_fieldbody_cr);
     }
     else if (ch == '\n')
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = '\0';
+      *_headerdataPtr++ = '\0';
       SET_STATE(state_fieldbody_crlf);
     }
     else if (!std::isspace(ch))
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = ch;
+      *_headerdataPtr++ = ch;
       SET_STATE(state_fieldbody);
     }
     return false;
@@ -157,19 +157,19 @@ namespace tnt
     if (ch == '\r')
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = '\0';
+      *_headerdataPtr++ = '\0';
       SET_STATE(state_fieldbody_cr);
     }
     else if (ch == '\n')
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = '\0';
+      *_headerdataPtr++ = '\0';
       SET_STATE(state_fieldbody_crlf);
     }
     else
     {
       checkHeaderspace(1);
-      *headerdataPtr++ = ch;
+      *_headerdataPtr++ = ch;
     }
     return false;
   }
@@ -181,7 +181,7 @@ namespace tnt
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in fieldbody-cr");
-      failedFlag = true;
+      _failedFlag = true;
       return true;
     }
     return false;
@@ -193,40 +193,40 @@ namespace tnt
       SET_STATE(state_end_cr);
     else if (ch == '\n')
     {
-      log_debug("header " << fieldnamePtr << ": " << fieldbodyPtr);
-      if (header.onField(fieldnamePtr, fieldbodyPtr) == FAIL)
+      log_debug("header " << _fieldnamePtr << ": " << _fieldbodyPtr);
+      if (_header.onField(_fieldnamePtr, _fieldbodyPtr) == FAIL)
       {
-        failedFlag = true;
+        _failedFlag = true;
         log_warn("invalid character " << chartoprint(ch) << " in fieldbody");
       }
 
-      *headerdataPtr = '\0';
+      *_headerdataPtr = '\0';
       return true;
     }
     else if (std::isspace(ch))
     {
       // continuation line
       checkHeaderspace(1);
-      *(headerdataPtr - 1) = '\n';
-      *headerdataPtr++ = ch;
+      *(_headerdataPtr - 1) = '\n';
+      *_headerdataPtr++ = ch;
       SET_STATE(state_fieldbody);
     }
     else if (ch >= 33 && ch <= 126)
     {
-      switch (header.onField(fieldnamePtr, fieldbodyPtr))
+      switch (_header.onField(_fieldnamePtr, _fieldbodyPtr))
       {
         case OK:   SET_STATE(state_fieldname);
                    break;
-        case FAIL: failedFlag = true;
+        case FAIL: _failedFlag = true;
                    log_warn("invalid character " << chartoprint(ch) << " in fieldbody");
                    break;
         case END:  return true;
                    break;
       }
 
-      fieldnamePtr = headerdataPtr;
+      _fieldnamePtr = _headerdataPtr;
       checkHeaderspace(1);
-      *headerdataPtr++ = ch;
+      *_headerdataPtr++ = ch;
     }
     return false;
   }
@@ -235,19 +235,19 @@ namespace tnt
   {
     if (ch == '\n')
     {
-      if (header.onField(fieldnamePtr, fieldbodyPtr) == FAIL)
+      if (_header.onField(_fieldnamePtr, _fieldbodyPtr) == FAIL)
       {
-        log_warn("invalid header " << fieldnamePtr << ' ' << fieldbodyPtr);
-        failedFlag = true;
+        log_warn("invalid header " << _fieldnamePtr << ' ' << _fieldbodyPtr);
+        _failedFlag = true;
       }
 
-      *headerdataPtr = '\0';
+      *_headerdataPtr = '\0';
       return true;
     }
     else
     {
       log_warn("invalid character " << chartoprint(ch) << " in end-cr");
-      failedFlag = true;
+      _failedFlag = true;
       return true;
     }
     return false;
@@ -255,17 +255,18 @@ namespace tnt
 
   void Messageheader::Parser::checkHeaderspace(unsigned chars) const
   {
-    if (headerdataPtr + chars >= header.rawdata + sizeof(header.rawdata))
+    if (_headerdataPtr + chars >= _header._rawdata + sizeof(_header._rawdata))
     {
-      header.rawdata[sizeof(header.rawdata) - 1] = '\0';
+      _header._rawdata[sizeof(_header._rawdata) - 1] = '\0';
       throw HttpError(HTTP_REQUEST_ENTITY_TOO_LARGE, "header too large");
     }
   }
 
   void Messageheader::Parser::reset()
   {
-    failedFlag = false;
-    headerdataPtr = header.rawdata;
+    _failedFlag = false;
+    _headerdataPtr = _header._rawdata;
     SET_STATE(state_0);
   }
 }
+
