@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -39,26 +39,25 @@ namespace tnt
 {
   class DeflateError : public std::runtime_error
   {
-      int zRet;
+      int _zRet;
 
     public:
-      DeflateError(int zRet_, const std::string& msg)
+      DeflateError(int zRet, const std::string& msg)
         : std::runtime_error(msg),
-          zRet(zRet_)
+          _zRet(zRet)
           { }
 
-      int getRet() const  { return zRet; }
+      int getRet() const { return _zRet; }
   };
 
   class DeflateStreamBuf : public std::streambuf
   {
-      z_stream stream;
-      std::vector<char_type> obuffer;
-      std::streambuf* sink;
+      z_stream _stream;
+      std::vector<char_type> _obuffer;
+      std::streambuf* _sink;
 
     public:
-      explicit DeflateStreamBuf(std::streambuf* sink_, int level = Z_DEFAULT_COMPRESSION,
-        unsigned bufsize = 8192);
+      explicit DeflateStreamBuf(std::streambuf* sink_, int level, int windowBits, unsigned bufsize);
       ~DeflateStreamBuf();
 
       /// see std::streambuf
@@ -70,28 +69,31 @@ namespace tnt
 
       /// end deflate-stream
       int end();
-      void setSink(std::streambuf* sink_)   { sink = sink_; }
-      uLong getAdler() const                { return stream.adler; }
+      void reinitialize();
+      void setSink(std::streambuf* sink) { _sink = sink; }
+      uLong getAdler() const             { return _stream.adler; }
   };
 
   class DeflateStream : public std::ostream
   {
-      DeflateStreamBuf streambuf;
+      DeflateStreamBuf _streambuf;
 
     public:
-      explicit DeflateStream(std::streambuf* sink, int level = Z_DEFAULT_COMPRESSION)
+      explicit DeflateStream(std::streambuf* sink, int level = Z_DEFAULT_COMPRESSION, int windowBits = 16 + MAX_WBITS)
         : std::ostream(0),
-          streambuf(sink, level)
-        { init(&streambuf); }
-      explicit DeflateStream(std::ostream& sink, int level = Z_DEFAULT_COMPRESSION)
+          _streambuf(sink, level, windowBits, 8192)
+          { init(&_streambuf); }
+      explicit DeflateStream(std::ostream& sink, int level = Z_DEFAULT_COMPRESSION, int windowBits = 16 + MAX_WBITS)
         : std::ostream(0),
-          streambuf(sink.rdbuf(), level)
-        { init(&streambuf); }
+          _streambuf(sink.rdbuf(), level, windowBits, 8192)
+          { init(&_streambuf); }
 
       void end();
-      void setSink(std::streambuf* sink)   { streambuf.setSink(sink); }
-      void setSink(std::ostream& sink)     { streambuf.setSink(sink.rdbuf()); }
-      uLong getAdler() const   { return streambuf.getAdler(); }
+      void reinitialize()
+      { _streambuf.reinitialize(); }
+      void setSink(std::streambuf* sink) { _streambuf.setSink(sink); }
+      void setSink(std::ostream& sink)   { _streambuf.setSink(sink.rdbuf()); }
+      uLong getAdler() const             { return _streambuf.getAdler(); }
   };
 }
 
