@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -38,18 +38,16 @@ namespace tnt
 {
   class HttpReturn
   {
-      unsigned returncode;
-      const char* msg;
+      unsigned _returncode;
+      const char* _msg;
 
     public:
       explicit HttpReturn(unsigned errcode);
-      HttpReturn(unsigned errcode_, const char* msg_);
+      HttpReturn(unsigned errcode, const char* msg);
 
-      unsigned getReturnCode() const
-        { return returncode; }
+      unsigned getReturnCode() const { return _returncode; }
 
-      const char* getMessage() const
-        { return msg; }
+      const char* getMessage() const { return _msg; }
 
       static const char* httpMessage(unsigned httpstatus);
   };
@@ -57,8 +55,8 @@ namespace tnt
   /// HTTP-error-class
   class HttpError : public std::exception, public HttpMessage
   {
-      std::string msg;
-      std::string body;
+      std::string _msg;
+      std::string _body;
 
     public:
       explicit HttpError(unsigned errcode);
@@ -67,36 +65,36 @@ namespace tnt
       ~HttpError() throw() { }
 
       const char* what() const throw ()
-      { return msg.c_str(); }
+        { return _msg.c_str(); }
 
       std::string getErrcodeStr() const
-      { return msg.substr(0, 3); }
+        { return _msg.substr(0, 3); }
 
       unsigned getErrcode() const
       {
-        return (msg[0] - '0') * 100
-             + (msg[1] - '0') * 10
-             + (msg[2] - '0');
+        return (_msg[0] - '0') * 100
+             + (_msg[1] - '0') * 10
+             + (_msg[2] - '0');
       }
 
       std::string getErrmsg() const;
 
       /// returns the body of the message.
-      const std::string& getBody() const        { return body; }
+      const std::string& getBody() const { return _body; }
   };
 
   /// HTTP-error 404
   class NotFoundException : public HttpError
   {
-      std::string url;
-      std::string vhost;
+      std::string _url;
+      std::string _vhost;
 
     public:
-      explicit NotFoundException(const std::string& url_, const std::string& vhost = std::string());
+      explicit NotFoundException(const std::string& url, const std::string& vhost = std::string());
       ~NotFoundException() throw() { }
 
-      const std::string& getUrl() const  { return url; }
-      const std::string& getVHost() const  { return vhost; }
+      const std::string& getUrl() const   { return _url; }
+      const std::string& getVHost() const { return _vhost; }
   };
 
   class NotAuthorized : public HttpError
@@ -113,3 +111,4 @@ namespace tnt
 }
 
 #endif // TNT_HTTPERROR_H
+
