@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -43,7 +43,6 @@ namespace tnt
     extern const char* connectionKeepAlive;
     extern const char* lastModified;
     extern const char* server;
-    extern const char* serverName;
     extern const char* location;
     extern const char* accept;
     extern const char* acceptLanguage;
@@ -69,7 +68,10 @@ namespace tnt
     extern const char* contentRange;
     extern const char* contentLocation;
     extern const char* contentDisposition;
+    extern const char* age;
+    extern const char* transferEncoding;
   }
 }
 
 #endif // TNT_HTTPHEADER_H
+
