@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2010 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,17 +15,18 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+
 #ifndef TNT_MBCOMPONENT_H
 #define TNT_MBCOMPONENT_H
 
@@ -38,46 +39,44 @@ namespace tnt
 
   class MbComponent : public EcppComponent
   {
-      const char* rawData;
-      const char** urls;
-      const char** mimetypes;
-      const char** ctimes;
-      std::vector<std::string> compressedData;
-      cxxtools::ReadWriteMutex mutex;
+      const char* _rawData;
+      const char** _urls;
+      const char** _mimetypes;
+      const char** _ctimes;
+      std::vector<std::string> _compressedData;
+      cxxtools::ReadWriteMutex _mutex;
 
     protected:
-      void init(const char* rawData_, const char** urls_,
-                const char** mimetypes_, const char** ctimes_);
-      void init(const char* rawData_, const char* &mimetype_, const char* &ctime_)
-      { init(rawData_, 0, &mimetype_, &ctime_); }
+      void init(const char* rawData, const char** urls, const char** mimetypes, const char** ctimes);
+      void init(const char* rawData, const char* &mimetype, const char* &ctime)
+        { init(rawData, 0, &mimetype, &ctime); }
 
     public:
       MbComponent(const Compident& ci, const Urlmapper& um, Comploader& cl)
         : EcppComponent(ci, um, cl),
-          rawData(0),
-          urls(0),
-          mimetypes(0),
-          ctimes(0)
-      { }
+          _rawData(0),
+          _urls(0),
+          _mimetypes(0),
+          _ctimes(0)
+        { }
+
+      MbComponent(const Compident& ci, const Urlmapper& um, Comploader& cl, const char* rawData,
+                  const char** urls, const char** mimetypes, const char** ctimes)
+        : EcppComponent(ci, um, cl),
+          _rawData(0),
+          _urls(0),
+          _mimetypes(0),
+          _ctimes(0)
+        { init(rawData, urls, mimetypes, ctimes); }
 
       MbComponent(const Compident& ci, const Urlmapper& um, Comploader& cl,
-                  const char* rawData_, const char** urls_,
-                  const char** mimetypes_, const char** ctimes_)
+                  const char* rawData, const char* &mimetype, const char* &ctime)
         : EcppComponent(ci, um, cl),
-          rawData(0),
-          urls(0),
-          mimetypes(0),
-          ctimes(0)
-      { init(rawData_, urls_, mimetypes_, ctimes_); }
-
-      MbComponent(const Compident& ci, const Urlmapper& um, Comploader& cl,
-                  const char* rawData_, const char* &mimetype_, const char* &ctime_)
-        : EcppComponent(ci, um, cl),
-          rawData(0),
-          urls(0),
-          mimetypes(0),
-          ctimes(0)
-      { init(rawData_, mimetype_, ctime_); }
+          _rawData(0),
+          _urls(0),
+          _mimetypes(0),
+          _ctimes(0)
+        { init(rawData, mimetype, ctime); }
 
       unsigned operator() (HttpRequest& request, HttpReply& reply, tnt::QueryParams& qparam);
       unsigned topCall(tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam);
@@ -88,3 +87,4 @@ namespace tnt
 }
 
 #endif // TNT_MBCOMPONENT_H
+
