@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -37,10 +37,10 @@ namespace tnt
 {
   class Messageheader::Parser : public tnt::Parser<Messageheader::Parser>
   {
-      Messageheader& header;
-      char* headerdataPtr;
-      char* fieldnamePtr;
-      char* fieldbodyPtr;
+      Messageheader& _header;
+      char* _headerdataPtr;
+      char* _fieldnamePtr;
+      char* _fieldbodyPtr;
 
       bool state_0(char ch);
       bool state_cr(char ch);
@@ -55,10 +55,12 @@ namespace tnt
       void checkHeaderspace(unsigned chars) const;
 
     public:
-      explicit Parser(Messageheader& header_)
+      explicit Parser(Messageheader& header)
         : tnt::Parser<Parser>(&Parser::state_0),
-          header(header_),
-          headerdataPtr(header.rawdata)
+          _header(header),
+          _headerdataPtr(header._rawdata),
+          _fieldnamePtr(0),
+          _fieldbodyPtr(0)
           { }
 
       void reset();
