@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2007 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -32,55 +32,60 @@
 
 #include <config.h>
 #include "tnt/job.h"
+#include "tnt/poller.h"
 #include <cxxtools/mutex.h>
 #include <cxxtools/posix/pipe.h>
 
-#ifdef WITH_EPOLL
+#if defined(HAVE_EPOLL_CREATE) || defined(HAVE_EPOLL_CREATE1)
+
+#  define WITH_EPOLL
 #  include <map>
+
 #else
+
 #  include <deque>
 #  include <vector>
 #  include <sys/poll.h>
+
 #endif
 
 namespace tnt
 {
+  /// @cond internal
   class PollerImpl : public PollerIf
   {
-      Jobqueue& queue;
+    private:
+      Jobqueue& _queue;
 
-      cxxtools::posix::Pipe notify_pipe;
+      cxxtools::posix::Pipe _notifyPipe;
+      cxxtools::Mutex _mutex;
 
 #ifdef WITH_EPOLL
 
-      int pollFd;
+      int _pollFd;
 
       typedef std::map<int, Jobqueue::JobPtr> jobs_type;
       typedef std::vector<Jobqueue::JobPtr> new_jobs_type;
-      jobs_type jobs;
-      new_jobs_type new_jobs;
-      int poll_timeout;
-
-      cxxtools::Mutex mutex;
+      jobs_type _jobs;
+      new_jobs_type _newJobs;
+      int _pollTimeout;
 
       void addFd(int fd);
       bool removeFd(int fd);
-      void append_new_jobs();
+      void appendNewJobs();
 
 #else
 
       typedef std::deque<Jobqueue::JobPtr> jobs_type;
       typedef std::vector<pollfd> pollfds_type;
 
-      jobs_type current_jobs;
-      pollfds_type pollfds;
+      jobs_type _currentJobs;
+      pollfds_type _pollfds;
+      jobs_type _newJobs;
 
-      jobs_type new_jobs;
+      int _pollTimeout;
 
-      cxxtools::Mutex mutex;
-      int poll_timeout;
-
-      void append_new_jobs();
+      void appendNewJobs();
       void append(Jobqueue::JobPtr& job);
       void dispatch();
       void remove(jobs_type::size_type n);
@@ -95,10 +100,9 @@ namespace tnt
 
       virtual void run();
       void doStop();
-      void addIdleJob(Jobqueue::JobPtr job);
+      void addIdleJob(Jobqueue::JobPtr& job);
   };
-
+  /// @endcond internal
 }
 
 #endif // TNT_POLLER_H
-
