@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -38,18 +38,18 @@ namespace tnt
 {
   class Sessionscope : public Scope
   {
-      time_t atime;
-      unsigned timeout;
+      time_t _atime;
+      cxxtools::Seconds _timeout;
 
     public:
       Sessionscope()
-        : timeout(TntConfig::it().sessionTimeout)
+        : _timeout(TntConfig::it().sessionTimeout)
         { touch(); }
 
-      void touch()                               { time(&atime); }
-      time_t getAtime() const                    { return atime; }
-      unsigned getTimeout() const                { return timeout; }
-      void setTimeout(unsigned t)                { timeout = t; }
+      void touch()                { time(&_atime); }
+      time_t getAtime() const     { return _atime; }
+      cxxtools::Seconds getTimeout() const { return _timeout; }
+      void setTimeout(cxxtools::Seconds t) { _timeout = t; }
   };
 }
 
