@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2009 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -32,18 +32,25 @@
 
 #include <string>
 
+namespace cxxtools
+{
+    class SslCertificate;
+}
+
+/// @cond internal
+
 namespace tnt
 {
   class SocketIf
   {
     protected:
-      virtual ~SocketIf()
-      { }
+      virtual ~SocketIf() { }
 
     public:
       virtual std::string getPeerIp() const = 0;
       virtual std::string getServerIp() const = 0;
       virtual bool isSsl() const = 0;
+      virtual cxxtools::SslCertificate getSslCertificate() const = 0;
   };
 }
 
