@@ -5,7 +5,7 @@
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,17 +15,18 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+
 #ifndef TNT_THREADCONTEXT_H
 #define TNT_THREADCONTEXT_H
 
@@ -33,16 +34,17 @@ namespace tnt
 {
   class Scope;
 
+  /// @cond internal
   class ThreadContext
   {
     protected:
-      virtual ~ThreadContext()
-      { }
+      virtual ~ThreadContext() { }
 
     public:
-      virtual void touch() = 0;       // wake watchdog timer
+      virtual void touch() = 0; // wake watchdog timer
       virtual Scope& getScope() = 0;
   };
 }
 
 #endif // TNT_THREADCONTEXT_H
+
