@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003/2006 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -38,21 +38,21 @@ namespace tnt
 {
   class unzipError : public std::runtime_error
   {
-      int err;
+      int _err;
 
       static std::string formatMsg(int e, const char* msg, const char* function);
 
     public:
       unzipError(int e, const std::string& msg = "unzipError")
         : std::runtime_error(msg),
-          err(e)
+          _err(e)
           { }
       unzipError(int e, const char* msg, const char* function)
         : std::runtime_error(formatMsg(e, msg, function)),
-          err(e)
+          _err(e)
           { }
 
-      int getErr() const  { return err; }
+      int getErr() const { return _err; }
   };
 
   class unzipFileNotFound : public unzipError
@@ -96,16 +96,16 @@ namespace tnt
   class unzipFile
   {
       struct unzFileStruct;
-      unzFileStruct* file;
+      unzFileStruct* _file;
 
     public:
       unzipFile()
-        : file(0)
+        : _file(0)
         { }
 
       unzipFile(const std::string& path)
-        : file(0)
-      { open(path); }
+        : _file(0)
+        { open(path); }
 
       ~unzipFile();
 
@@ -123,27 +123,27 @@ namespace tnt
 
   class unzipFileStreamBuf : public std::streambuf
   {
-      char_type buffer[512];
-      unzipFile& file;
+      char_type _buffer[512];
+      unzipFile& _file;
 
     public:
-      unzipFileStreamBuf(unzipFile& f, const std::string& fileName, bool caseSensitivity)
-        : file(f)
+      unzipFileStreamBuf(unzipFile& file, const std::string& fileName, bool caseSensitivity)
+        : _file(file)
       {
-        f.locateFile(fileName, caseSensitivity);
-        f.openCurrentFile();
+        file.locateFile(fileName, caseSensitivity);
+        file.openCurrentFile();
       }
 
-      unzipFileStreamBuf(unzipFile& f, const std::string& fileName, bool caseSensitivity,
+      unzipFileStreamBuf(unzipFile& file, const std::string& fileName, bool caseSensitivity,
         const std::string& password)
-        : file(f)
+        : _file(file)
       {
-        f.locateFile(fileName, caseSensitivity);
-        f.openCurrentFile(password);
+        file.locateFile(fileName, caseSensitivity);
+        file.openCurrentFile(password);
       }
 
       ~unzipFileStreamBuf()
-      { file.closeCurrentFile(); }
+        { _file.closeCurrentFile(); }
 
       /// overridden from std::streambuf
       int_type overflow(int_type c);
@@ -155,16 +155,15 @@ namespace tnt
 
   class unzipFileStream : public std::istream
   {
-      unzipFileStreamBuf streambuf;
+      unzipFileStreamBuf _streambuf;
 
     public:
-      unzipFileStream(unzipFile& f, const std::string& fileName, bool caseSensitivity = true)
+      unzipFileStream(unzipFile& file, const std::string& fileName, bool caseSensitivity = true)
         : std::istream(0),
-          streambuf(f, fileName, caseSensitivity)
-        { init(&streambuf); }
+          _streambuf(file, fileName, caseSensitivity)
+        { init(&_streambuf); }
   };
-
 }
 
-#endif // UNZIPFILE_H
+#endif // TNT_UNZIPFILE_H
 
