@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -34,10 +34,12 @@
 #include <cxxtools/thread.h>
 #include <cxxtools/mutex.h>
 #include <tnt/comploader.h>
-#include <tnt/tntnet.h>
+#include <tntnetimpl.h>
 #include <tnt/scope.h>
 #include <tnt/threadcontext.h>
 
+/// @cond internal
+
 namespace tnt
 {
   class HttpRequest;
@@ -45,23 +47,20 @@ namespace tnt
 
   class Worker : public cxxtools::DetachedThread, private ThreadContext
   {
-      static cxxtools::Mutex mutex;
-
-      Tntnet& application;
-
-      static Comploader comploader;
-
-      Scope threadScope;
-
-      pthread_t threadId;
-      const char* state;
-      time_t lastWaitTime;
-
       typedef std::set<Worker*> workers_type;
-      static workers_type workers;
 
-      bool processRequest(HttpRequest& request, std::iostream& socket,
-        unsigned keepAliveCount);
+      static cxxtools::Mutex _mutex;
+      TntnetImpl& _application;
+      static Comploader _comploader;
+
+      Scope _threadScope;
+      pthread_t _threadId;
+      const char* _state;
+      time_t _lastWaitTime;
+
+      static workers_type _workers;
+
+      bool processRequest(HttpRequest& request, std::iostream& socket, unsigned keepAliveCount);
       void logRequest(const HttpRequest& request, const HttpReply& reply, unsigned httpReturn);
       void healthCheck(time_t currentTime);
 
@@ -70,7 +69,7 @@ namespace tnt
       Scope& getScope();
 
     public:
-      explicit Worker(Tntnet& app);
+      explicit Worker(TntnetImpl& app);
 
       virtual void run();
 
@@ -81,7 +80,7 @@ namespace tnt
       static workers_type::size_type getCountThreads();
 
       static Comploader& getComponentLoader()
-      { return comploader; }
+        { return _comploader; }
   };
 }
 
