@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -30,34 +30,35 @@
 #ifndef TNT_ZDATA_H
 #define TNT_ZDATA_H
 
-#include <cxxtools/atomicity.h>
+#include <atomic>
 
+/// @cond internal
 namespace tnt
 {
   class Zdata
   {
-      const char* zptr;
-      const unsigned zdata_len;
-      const unsigned data_len;
+      const char* _zptr;
+      const unsigned _zdataLen;
+      const unsigned _dataLen;
 
-      cxxtools::atomic_t refs;
-      char* data;
+      std::atomic<unsigned> _refs;
+      char* _data;
 
     public:
-      Zdata(const char* zptr_, unsigned zdata_len_, unsigned data_len_)
-        : zptr(zptr_),
-          zdata_len(zdata_len_),
-          data_len(data_len_),
-          refs(0),
-          data(0)
-      { }
+      Zdata(const char* zptr, unsigned zdataLen, unsigned dataLen)
+        : _zptr(zptr),
+          _zdataLen(zdataLen),
+          _dataLen(dataLen),
+          _refs(0),
+          _data(0)
+        { }
 
       void addRef();
       void release();
 
-      operator const char* () const      { return data; }
+      operator const char* () const { return _data; }
   };
 }
+/// @endcond internal
 
 #endif // TNT_ZDATA_H
-
