@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -34,29 +34,25 @@ namespace tnt
 {
   std::streambuf::int_type UrlEscStreamBuf::overflow(std::streambuf::int_type ch)
   {
-    static char hex[] = "0123456789ABCDEF";
+    static const char hex[] = "0123456789ABCDEF";
     if (ch > 32 && ch < 127 && ch != '%' && ch != '+' && ch != '=' && ch != '&')
-      sink->sputc(ch);
+      _sink->sputc(ch);
     else if (ch == ' ')
-      sink->sputc('+');
+      _sink->sputc('+');
     else
     {
-      sink->sputc('%');
-      sink->sputc(hex[(ch >> 4) & 0x0f]);
-      sink->sputc(hex[ch & 0x0f]);
+      _sink->sputc('%');
+      _sink->sputc(hex[(ch >> 4) & 0x0f]);
+      _sink->sputc(hex[ch & 0x0f]);
     }
     return 0;
   }
 
   std::streambuf::int_type UrlEscStreamBuf::underflow()
-  {
-    return traits_type::eof();
-  }
+    { return traits_type::eof(); }
 
   int UrlEscStreamBuf::sync()
-  {
-    return sink->pubsync();
-  }
+    { return _sink->pubsync(); }
 
   std::string urlEscape(const std::string& str)
   {
@@ -65,5 +61,5 @@ namespace tnt
     e << str;
     return s.str();
   }
-
 }
+
