@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,17 +15,18 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+
 #include <tnt/component.h>
 #include <tnt/componentfactory.h>
 #include <tnt/httprequest.h>
@@ -40,46 +41,27 @@ namespace tnt
   class Comploader;
 
   ////////////////////////////////////////////////////////////////////////
-  // componentdeclaration
+  // component declaration
   //
   class Error : public tnt::Component
   {
-      friend class ErrorFactory;
+    friend class ErrorFactory;
 
     public:
-      Error()
-      { }
+      Error() { }
 
-      virtual unsigned operator() (tnt::HttpRequest& request,
-        tnt::HttpReply& reply, tnt::QueryParams& qparam);
+      virtual unsigned operator() (tnt::HttpRequest&, tnt::HttpReply&, tnt::QueryParams&);
   };
 
   ////////////////////////////////////////////////////////////////////////
   // factory
   //
-  class ErrorFactory : public tnt::ComponentFactory
-  {
-    public:
-      ErrorFactory(const std::string& componentName)
-        : tnt::ComponentFactory(componentName)
-        { }
-      virtual tnt::Component* doCreate(const tnt::Compident& ci,
-        const tnt::Urlmapper& um, tnt::Comploader& cl);
-  };
-
-  tnt::Component* ErrorFactory::doCreate(const tnt::Compident&,
-    const tnt::Urlmapper&, tnt::Comploader&)
-  {
-    return new Error();
-  }
-
-  static ErrorFactory errorFactory("error");
+  static ComponentFactoryImpl<Error> errorFactory("error");
 
   ////////////////////////////////////////////////////////////////////////
-  // componentdefinition
+  // component definition
   //
-  unsigned Error::operator() (tnt::HttpRequest& request,
-    tnt::HttpReply& reply, tnt::QueryParams&)
+  unsigned Error::operator() (tnt::HttpRequest& request, tnt::HttpReply&, tnt::QueryParams&)
   {
     std::istringstream s(request.getArg("code"));
     unsigned errorcode;
@@ -88,10 +70,12 @@ namespace tnt
       throw tnt::HttpError(HTTP_INTERNAL_SERVER_ERROR, "configuration error");
 
     std::string msg = request.getArg("message");
+    if (msg.empty())
+      msg = HttpReturn::httpMessage(errorcode);
 
     throw tnt::HttpError(errorcode, msg);
 
     return DECLINED;
   }
-
 }
+
