@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003,2007 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,17 +15,18 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+
 #include "static.h"
 #include "mimehandler.h"
 #include <tnt/httprequest.h>
@@ -34,10 +35,12 @@
 #include <tnt/http.h>
 #include <tnt/httpheader.h>
 #include <tnt/comploader.h>
+#include <tnt/tntconfig.h>
 #include <fstream>
 #include <cxxtools/log.h>
 #include <cxxtools/systemerror.h>
 #include <cxxtools/ioerror.h>
+#include <cxxtools/convert.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <config.h>
@@ -76,8 +79,6 @@ namespace tnt
         state_e
       } state = state_0;
 
-      std::string token;
-
       const char* prefix = "bytes=";
       off_t firstPos = 0;
       off_t lastPos = count;
@@ -153,7 +154,7 @@ namespace tnt
               return false;
             break;
 
-          case state_e:
+          case state_e: // not reachable but to satisfy the compiler we put it here
             break;
         }
       }
@@ -182,22 +183,23 @@ namespace tnt
 #if defined(HAVE_SENDFILE) && defined(HAVE_SYS_SENDFILE_H)
     class Fdfile
     {
-        int fd;
+      private:
+        int _fd;
       public:
         Fdfile(const char* pathname, int flags)
-          : fd(open(pathname, flags))
+          : _fd(open(pathname, flags))
         {
-          if (fd < 0)
+          if (_fd < 0)
             throw cxxtools::SystemError("open");
         }
 
         ~Fdfile()
         {
-          if (fd >= 0)
-            ::close(fd);
+          if (_fd >= 0)
+            ::close(_fd);
         }
 
-        int getFd() const  { return fd; }
+        int getFd() const { return _fd; }
     };
 
     void pollout(int fd, int timeout)
@@ -227,58 +229,44 @@ namespace tnt
 #endif
   }
 
-  Component* StaticFactory::doCreate(const Compident&,
-    const Urlmapper&, Comploader&)
-  {
-    return new Static();
-  }
-
-  void StaticFactory::doConfigure(const TntConfig& config)
-  {
-    if (Static::handler == 0)
-      Static::handler = new MimeHandler();
-  }
-
-  static StaticFactory staticFactory("static");
+  //////////////////////////////////////////////////////////////////////
+  // factory
+  //
+  static ComponentFactoryImpl<Static> staticFactory("static");
 
   //////////////////////////////////////////////////////////////////////
-  // componentdefinition
+  // component definition
   //
-  std::string Static::configDocumentRoot = "DocumentRoot";
-  MimeHandler* Static::handler;
+  Static::~Static()
+    { delete _handler; }
+
+  void Static::configure(const TntConfig&)
+  {
+    if (_handler == 0)
+      _handler = new MimeHandler();
+  }
 
   void Static::setContentType(HttpRequest& request, HttpReply& reply)
   {
-    if (handler)
-      reply.setContentType(handler->getMimeType(request.getPathInfo()).c_str());
+    if (_handler)
+      reply.setContentType(_handler->getMimeType(request.getPathInfo()).c_str());
   }
 
-  unsigned Static::operator() (HttpRequest& request,
-    HttpReply& reply, QueryParams& qparams)
-  {
-    return doCall(request, reply, qparams, false);
-  }
+  unsigned Static::operator() (HttpRequest& request, HttpReply& reply, QueryParams& qparam)
+    { return doCall(request, reply, qparam, false); }
 
-  unsigned Static::topCall(HttpRequest& request,
-    HttpReply& reply, QueryParams& qparams)
-  {
-    return doCall(request, reply, qparams, true);
-  }
+  unsigned Static::topCall(HttpRequest& request, HttpReply& reply, QueryParams& qparam)
+    { return doCall(request, reply, qparam, true); }
 
-  unsigned Static::doCall(HttpRequest& request,
-    HttpReply& reply, QueryParams& qparams, bool top)
+  unsigned Static::doCall(HttpRequest& request, HttpReply& reply, QueryParams&, bool top)
   {
-    if (!HttpRequest::checkUrl(request.getPathInfo()))
-      throw HttpError(HTTP_BAD_REQUEST, "illegal url");
+    if (!tnt::HttpRequest::checkUrl(request.getPathInfo()) ||
+        request.getPathInfo().find('\0') != std::string::npos)
+      throw tnt::HttpError(HTTP_BAD_REQUEST, "illegal url");
 
-    std::string file = request.getArg(configDocumentRoot); // fetch document root from arguments first
-    if (file.empty())
-    {
-      if (!TntConfig::it().documentRoot.empty())
-        file = TntConfig::it().documentRoot;
-    }
-    else
-      log_debug("document root \"" << file << "\" got as argument");
+    // fetch document root from arguments or take global setting as default
+    std::string file = request.getArg("documentRoot", TntConfig::it().documentRoot);
+    log_debug("document root =\"" << file << '"');
 
     if (!file.empty() && *file.rbegin() != '/')
       file += '/';
@@ -321,132 +309,149 @@ namespace tnt
       }
     }
 
-    std::string lastModified = HttpMessage::htdate(st.st_ctime);
-
-    {
-      std::string s = request.getHeader(httpheader::ifModifiedSince);
-      if (s == lastModified)
-        return HTTP_NOT_MODIFIED;
-    }
-
-    // set Content-Type
-    std::string contentType = request.getArg("ContentType");
-    if (!contentType.empty())
-    {
-      log_debug("content type is \"" << contentType << '"');
-      reply.setContentType(contentType.c_str());
-    }
-    else
-      setContentType(request, reply);
-
-    reply.setHeader(httpheader::lastModified, lastModified);
-
-    // set Keep-Alive
-    reply.setKeepAliveHeader();
-
-    reply.setHeader(httpheader::acceptRanges, "bytes");
-
-    // check for byte range (only "bytes=from-" or "bytes=from-to" are supported)
-    const char* range = request.getHeader(httpheader::range);
     off_t offset = 0;
     off_t count = st.st_size;
     unsigned httpOkReturn = HTTP_OK;
-    if (range)
+
+    if (top)
     {
-      if (parseRange(range, offset, count))
+      // set Content-Type
+      std::string contentType = request.getArg("contentType");
+      if (!contentType.empty())
       {
-        if (offset > st.st_size)
-          return HTTP_RANGE_NOT_SATISFIABLE;
-
-        reply.setHeader(httpheader::contentLocation, request.getUrl());
-        std::ostringstream contentRange;
-        contentRange << offset << '-' << (offset+count)-1 << '/' << st.st_size;
-        reply.setHeader(httpheader::contentRange, contentRange.str());
-
-        httpOkReturn = HTTP_PARTIAL_CONTENT;
+        log_debug("content type is \"" << contentType << '"');
+        reply.setContentType(contentType.c_str());
       }
       else
-        log_debug("ignore invalid byte range " << range);
-    }
+        setContentType(request, reply);
 
-    // set Content-Length
-    reply.setContentLengthHeader(count);
+      std::string lastModified = HttpMessage::htdate(st.st_ctime);
 
-    if (request.isMethodHEAD())
-    {
-      log_debug("head request");
-      return httpOkReturn;
-    }
-    else
-    {
-      log_debug("no head request");
-    }
-
-    // send data
-    log_info("send file \"" << file << "\" size " << st.st_size << " bytes; offset=" << offset << " count=" << count);
-
-#if defined(HAVE_SENDFILE) && defined(HAVE_SYS_SENDFILE_H)
-    if (top)
-    {
-      int on = 1;
-      int off = 0;
-      try
       {
-        cxxtools::net::iostream& tcpStream = dynamic_cast<cxxtools::net::iostream&>(reply.getDirectStream());
+        std::string s = request.getHeader(httpheader::ifModifiedSince);
+        if (s == lastModified)
+          return HTTP_NOT_MODIFIED;
+      }
 
-        if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_NODELAY,
-            &off, sizeof(off)) < 0)
-          throw cxxtools::SystemError("setsockopt(TCP_NODELAY)");
+      reply.setHeader(httpheader::lastModified, lastModified);
+      reply.setKeepAliveHeader();
+      reply.setHeader(httpheader::acceptRanges, "bytes");
 
-        if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_CORK,
-            &on, sizeof(on)) < 0)
-          throw cxxtools::SystemError("setsockopt(TCP_CORK)");
+      if (!reply.hasHeader(httpheader::cacheControl))
+      {
+        std::string maxAgeStr = request.getArg("maxAge");
+        unsigned maxAge = maxAgeStr.empty() ? 14400 : cxxtools::convert<unsigned>(maxAgeStr);
+        reply.setMaxAgeHeader(maxAge);
+      }
 
-        reply.setDirectMode(httpOkReturn, HttpReturn::httpMessage(httpOkReturn));
-        tcpStream.flush();
-
-        Fdfile in(file.c_str(), O_RDONLY);
-        ssize_t s;
-        while(tcpStream)
+      // check for byte range (only "bytes=from-" or "bytes=from-to" are supported)
+      const char* range = request.getHeader(httpheader::range, 0);
+      if (range)
+      {
+        if (parseRange(range, offset, count))
         {
-          do
-          {
-            log_debug("sendfile offset " << offset << " size " << count);
-            s = sendfile(tcpStream.getFd(), in.getFd(), &offset, count);
-            log_debug("sendfile returns " << s);
-          } while (s < 0 && errno == EINTR);
+          if (offset > st.st_size)
+            return HTTP_RANGE_NOT_SATISFIABLE;
 
-          if (s < 0 && errno != EAGAIN)
-            throw cxxtools::SystemError("sendfile");
+          if (offset + count > st.st_size)
+            count = st.st_size - offset;
 
-          if (offset >= count)
-            break;
+          reply.setHeader(httpheader::contentLocation, request.getUrl());
+          std::ostringstream contentRange;
+          contentRange << offset << '-' << (offset+count)-1 << '/' << st.st_size;
+          reply.setHeader(httpheader::contentRange, contentRange.str());
 
-          log_debug("poll");
-          pollout(tcpStream.getFd(), tcpStream.getTimeout());
+          httpOkReturn = HTTP_PARTIAL_CONTENT;
         }
+        else
+        {
+          log_debug("invalid byte range " << range);
+          return HTTP_RANGE_NOT_SATISFIABLE;
+        }
+      }
 
-        if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_CORK,
-            &off, sizeof(off)) < 0)
-          throw cxxtools::SystemError("setsockopt(TCP_CORK)");
-
-        if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_NODELAY,
-            &on, sizeof(on)) < 0)
-          throw cxxtools::SystemError("setsockopt(TCP_NODELAY)");
+      // set Content-Length
+      reply.setContentLengthHeader(reply.getContentSize() + count);
 
+      if (request.isMethodHEAD())
+      {
+        log_debug("head request");
         return httpOkReturn;
       }
-      catch (const std::bad_cast& e)
+      else
       {
-        log_debug("stream is no tcpstream - don't use sendfile");
-        reply.setDirectMode();
+        log_debug("no head request");
+      }
+
+      // send data
+      log_info("send file \"" << file << "\" size " << st.st_size << " bytes; offset=" << offset << " count=" << count);
+
+#if defined(HAVE_SENDFILE) && defined(HAVE_SYS_SENDFILE_H)
+      if (request.isSsl())
+      {
+        log_debug("no sendfile on ssl");
+      }
+      else
+      {
+        try
+        {
+          int on = 1;
+          int off = 0;
+
+          cxxtools::net::iostream& tcpStream = dynamic_cast<cxxtools::net::iostream&>(reply.getDirectStream());
+
+          if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_NODELAY,
+              &off, sizeof(off)) < 0)
+            throw cxxtools::SystemError("setsockopt(TCP_NODELAY)");
+
+          if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_CORK,
+              &on, sizeof(on)) < 0)
+            throw cxxtools::SystemError("setsockopt(TCP_CORK)");
+
+          reply.setDirectMode(httpOkReturn, HttpReturn::httpMessage(httpOkReturn));
+          tcpStream.flush();
+
+          Fdfile in(file.c_str(), O_RDONLY);
+          ssize_t s;
+          while(tcpStream)
+          {
+            do
+            {
+              log_debug("sendfile offset " << offset << " size " << count);
+              s = sendfile(tcpStream.getFd(), in.getFd(), &offset, count);
+              log_debug("sendfile returns " << s);
+            } while (s < 0 && errno == EINTR);
+
+            if (s < 0 && errno != EAGAIN)
+              throw cxxtools::SystemError("sendfile");
+
+            if (offset >= count || s == 0)
+              break;
+
+            log_debug("poll");
+            pollout(tcpStream.getFd(), tcpStream.getTimeout());
+          }
+
+          if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_CORK,
+              &off, sizeof(off)) < 0)
+            throw cxxtools::SystemError("setsockopt(TCP_CORK)");
+
+          if (::setsockopt(tcpStream.getFd(), SOL_TCP, TCP_NODELAY,
+              &on, sizeof(on)) < 0)
+            throw cxxtools::SystemError("setsockopt(TCP_NODELAY)");
+
+          return httpOkReturn;
+        }
+        catch (const std::bad_cast& e)
+        {
+          log_debug("stream is no tcpstream - don't use sendfile");
+        }
       }
-    }
-#else
-    if (top)
-      reply.setDirectMode();
 #endif
 
+      reply.setDirectMode();
+    }
+
     std::ifstream in(file.c_str());
     in.seekg(offset);
     if (!in)
@@ -455,7 +460,7 @@ namespace tnt
       return DECLINED;
     }
 
-    if (offset == 0 && count == st.st_size)
+    if (offset == 0 && count == st.st_size && count > 0)
     {
       reply.out() << in.rdbuf() << std::flush;
       if (in.fail())
@@ -473,5 +478,5 @@ namespace tnt
 
     return httpOkReturn;
   }
-
 }
+
