@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2003 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,17 +15,18 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+
 #include "static.h"
 #include "unzip.h"
 
@@ -45,44 +46,22 @@ namespace tnt
   class MimeHandler;
 
   ////////////////////////////////////////////////////////////////////////
-  // componentdeclaration
+  // component declaration
   //
   class Unzip : public Static
   {
-      friend class UnzipFactory;
+    friend class UnzipFactory;
 
     public:
-      virtual unsigned operator() (tnt::HttpRequest& request,
-        tnt::HttpReply& reply, tnt::QueryParams& qparam);
+      virtual unsigned operator() (tnt::HttpRequest&, tnt::HttpReply&, tnt::QueryParams&);
   };
 
-  ////////////////////////////////////////////////////////////////////////
-  // factory
-  //
-  class UnzipFactory : public StaticFactory
-  {
-    public:
-      UnzipFactory(const std::string& componentName)
-        : StaticFactory(componentName)
-        { }
-      virtual tnt::Component* doCreate(const tnt::Compident& ci,
-        const tnt::Urlmapper& um, tnt::Comploader& cl);
-  };
-
-  tnt::Component* UnzipFactory::doCreate(const tnt::Compident&,
-    const tnt::Urlmapper&, tnt::Comploader&)
-  {
-    return new Unzip();
-  }
-
-  static UnzipFactory unzipFactory("unzip");
+  static ComponentFactoryImpl<Unzip> factory("unzip");
 
   ////////////////////////////////////////////////////////////////////////
-  // componentdefinition
+  // component definition
   //
-
-  unsigned Unzip::operator() (tnt::HttpRequest& request,
-    tnt::HttpReply& reply, tnt::QueryParams& qparams)
+  unsigned Unzip::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams&)
   {
     std::string pi = request.getPathInfo();
 
@@ -110,5 +89,5 @@ namespace tnt
 
     return HTTP_OK;
   }
-
 }
+
