@@ -31,6 +31,7 @@
 #define TNT_ECPP_PARSERHANDLER_H
 
 #include <tnt/ecpp/parser.h>
+#include <vector>
 
 namespace tnt
 {
@@ -43,10 +44,9 @@ namespace tnt
         typedef Parser::cppargs_type cppargs_type;
         typedef Parser::paramargs_type paramargs_type;
 
-        ParseHandler()
-          { }
+        ParseHandler() { }
 
-        virtual ~ParseHandler() {}
+        virtual ~ParseHandler() { }
 
         virtual void start();
         virtual void end();
@@ -61,15 +61,15 @@ namespace tnt
         virtual void onArg(const std::string& name, const std::string& value);
         virtual void onGet(const std::string& name, const std::string& value);
         virtual void onPost(const std::string& name, const std::string& value);
-        virtual void onAttr(const std::string& name,
-          const std::string& value);
-        virtual void onCall(const std::string& comp,
-          const comp_args_type& args, const std::string& pass_cgi,
-          const paramargs_type& paramargs, const std::string& cppargs);
+        virtual void onAttr(const std::string& name, const std::string& value);
+        virtual void onCall(const std::string& comp, const comp_args_type& args,
+                            const std::string& passCgi, const paramargs_type& paramargs,
+                            const std::string& cppargs);
         virtual void onEndCall(const std::string& comp);
         virtual void onShared(const std::string& code);
         virtual void onScope(scope_container_type container, scope_type scope,
-          const std::string& type, const std::string& var, const std::string& init);
+                             const std::string& type, const std::string& var,
+                             const std::string& init, const std::vector<std::string>& includes);
         virtual void startComp(const std::string& name, const cppargs_type& cppargs);
         virtual void startClose();
         virtual void endClose();
@@ -79,10 +79,7 @@ namespace tnt
         virtual void tokenSplit(bool start);
         virtual void onInclude(const std::string& file);
         virtual void onIncludeEnd(const std::string& file);
-        virtual void startI18n();
-        virtual void endI18n();
     };
-
   }
 }
 
