@@ -52,7 +52,8 @@ namespace tnt
 
     enum scope_type
     {
-      global_scope,
+      default_scope,
+      shared_scope,
       page_scope,
       component_scope
     };
