@@ -47,6 +47,7 @@ namespace tnt
     {
       class BStringPrinter
       {
+        private:
           std::ostream& out;
           unsigned mincol, maxcol, col;
 
@@ -85,75 +86,69 @@ namespace tnt
         }
         out << d;
       }
-    }
+    } // namespace
 
-    ////////////////////////////////////////////////////////////////////////
-    // Generator
-    //
     Generator::Generator(const std::string& componentName)
-      : raw(false),
-        maincomp(componentName),
-        haveCloseComp(false),
-        closeComp(componentName),
-        currentComp(&maincomp),
-        externData(false),
-        compress(false),
-        c_time(0),
-        linenumbersEnabled(true)
+      : _raw(false),
+        _maincomp(componentName),
+        _haveCloseComp(false),
+        _closeComp(componentName),
+        _currentComp(&_maincomp),
+        _compress(false),
+        _c_time(0),
+        _linenumbersEnabled(true)
     {
       time_t cur;
       time(&cur);
-      gentime = asctime(localtime(&cur));
+      _gentime = asctime(localtime(&cur));
     }
 
     bool Generator::hasScopevars() const
     {
-      if (maincomp.hasScopevars())
+      if (_maincomp.hasScopevars())
         return true;
-      for (subcomps_type::const_iterator it = subcomps.begin(); it != subcomps.end(); ++it)
+      for (subcomps_type::const_iterator it = _subcomps.begin(); it != _subcomps.end(); ++it)
         if (it->hasScopevars())
           return true;
       return false;
     }
 
     void Generator::addImage(const std::string& name, const std::string& content,
-        const std::string& mime, time_t c_time_)
+        const std::string& mime, time_t c_time)
     {
       MultiImageType mi;
       mi.name = name;
       mi.mime = mime;
-      mi.c_time = c_time_;
-      multiImages.push_back(mi);
+      mi.c_time = c_time;
+      _multiImages.push_back(mi);
 
-      data.push_back(content);
+      _data.push_back(content);
     }
 
     void Generator::onLine(unsigned lineno, const std::string& file)
     {
       log_debug("onLine(" << lineno << ", \"" << file << "\")");
-      curline = lineno;
-      curfile = file;
+      _curline = lineno;
+      _curfile = file;
     }
 
     void Generator::onHtml(const std::string& html)
     {
       log_debug("onHtml(\"" << html << "\")");
 
-      data.push_back(html);
+      _data.push_back(html);
 
       std::ostringstream m;
-      m << "  reply.out() << data[" << (data.count() - 1) << "]; // ";
+      m << "  reply.out() << _tntChunks[" << (_data.count() - 1) << "]; // ";
 
-      std::transform(
-        html.begin(),
-        html.end(),
+      std::transform(html.begin(), html.end(),
         std::ostream_iterator<const char*>(m),
         stringescaper(false));
 
       m << '\n';
-      currentComp->addHtml(m.str());
+      _currentComp->addHtml(m.str());
 
-      log_debug("onHtml(\"" << html << "\") end, data.size()=" << data.count());
+      log_debug("onHtml(\"" << html << "\") end, _tntChunks.size()=" << _data.count());
     }
 
     void Generator::onExpression(const std::string& expr)
@@ -161,7 +156,7 @@ namespace tnt
       std::ostringstream m;
       printLine(m);
       m << "  reply.sout() << (" << expr << ");\n";
-      currentComp->addHtml(m.str());
+      _currentComp->addHtml(m.str());
     }
 
     void Generator::onHtmlExpression(const std::string& expr)
@@ -169,7 +164,7 @@ namespace tnt
       std::ostringstream m;
       printLine(m);
       m << "  reply.out() << (" << expr << ");\n";
-      currentComp->addHtml(m.str());
+      _currentComp->addHtml(m.str());
     }
 
     void Generator::onCpp(const std::string& code)
@@ -177,7 +172,7 @@ namespace tnt
       std::ostringstream m;
       printLine(m);
       m << code << '\n';
-      currentComp->addHtml(m.str());
+      _currentComp->addHtml(m.str());
     }
 
     void Generator::onPre(const std::string& code)
@@ -185,7 +180,7 @@ namespace tnt
       std::ostringstream m;
       printLine(m);
       m << code << '\n';
-      pre += m.str();
+      _pre += m.str();
     }
 
     void Generator::onInit(const std::string& code)
@@ -193,7 +188,7 @@ namespace tnt
       std::ostringstream m;
       printLine(m);
       m << code << '\n';
-      init += m.str();
+      _init += m.str();
     }
 
     void Generator::onCleanup(const std::string& code)
@@ -201,78 +196,59 @@ namespace tnt
       std::ostringstream m;
       printLine(m);
       m << code << '\n';
-      cleanup += m.str();
+      _cleanup += m.str();
     }
 
-    void Generator::onArg(const std::string& name,
-      const std::string& value)
-    {
-      currentComp->addArg(name, value);
-    }
+    void Generator::onArg(const std::string& name, const std::string& value)
+      { _currentComp->addArg(name, value); }
 
-    void Generator::onGet(const std::string& name,
-      const std::string& value)
-    {
-      currentComp->addGet(name, value);
-    }
+    void Generator::onGet(const std::string& name, const std::string& value)
+      { _currentComp->addGet(name, value); }
 
     void Generator::onPost(const std::string& name,
       const std::string& value)
-    {
-      currentComp->addPost(name, value);
-    }
+      { _currentComp->addPost(name, value); }
 
     void Generator::onAttr(const std::string& name,
       const std::string& value)
     {
-      if (attr.find(name) != attr.end())
+      if (_attr.find(name) != _attr.end())
         throw std::runtime_error("duplicate attr " + name);
-      attr.insert(attr_type::value_type(name, value));
+      _attr.insert(attr_type::value_type(name, value));
     }
 
-    void Generator::onCall(const std::string& comp,
-      const comp_args_type& args, const std::string& pass_cgi,
-      const paramargs_type& paramargs, const std::string& cppargs)
-    {
-      currentComp->addCall(curline, curfile, comp, args, pass_cgi, paramargs, cppargs);
-    }
+    void Generator::onCall(const std::string& comp, const comp_args_type& args,
+                           const std::string& passCgi, const paramargs_type& paramargs,
+                           const std::string& cppargs)
+      { _currentComp->addCall(_curline, _curfile, comp, args, passCgi, paramargs, cppargs); }
 
     void Generator::onEndCall(const std::string& comp)
-    {
-      currentComp->addEndCall(curline, curfile, comp);
-    }
+      { _currentComp->addEndCall(_curline, _curfile, comp); }
 
     void Generator::onShared(const std::string& code)
+      { _shared += code; }
+
+    void Generator::startComp(const std::string& name, const cppargs_type& cppargs)
     {
-      shared += code;
+      _subcomps.push_back(Subcomponent(name, _maincomp, cppargs));
+      Subcomponent& s = _subcomps.back();
+      _currentComp = &s;
+      _maincomp.addSubcomp(name);
     }
 
-    void Generator::startComp(const std::string& name,
-      const cppargs_type& cppargs)
-    {
-      subcomps.push_back(Subcomponent(name, maincomp, cppargs));
-      Subcomponent& s = subcomps.back();
-      currentComp = &s;
-      maincomp.addSubcomp(name);
-    }
-
-    void Generator::onComp(const std::string& code)
-    {
-      currentComp = &maincomp;
-    }
+    void Generator::onComp(const std::string& /* code */)
+      { _currentComp = &_maincomp; }
 
     void Generator::startClose()
     {
-      if (haveCloseComp)
-        throw std::runtime_error("dumplicate close-part");
-      haveCloseComp = true;
-      currentComp = &closeComp;
+      if (_haveCloseComp)
+        throw std::runtime_error("duplicate close-part");
+      _haveCloseComp = true;
+      _currentComp = &_closeComp;
     }
 
     void Generator::endClose()
-    {
-      currentComp = &maincomp;
-    }
+      { _currentComp = &_maincomp; }
 
     void Generator::onCondExpr(const std::string& cond, const std::string& expr, bool htmlexpr)
     {
@@ -284,37 +260,32 @@ namespace tnt
       else
         m << "    reply.sout() << ";
       m << expr << ";\n";
-      currentComp->addHtml(m.str());
+      _currentComp->addHtml(m.str());
     }
 
     void Generator::onConfig(const std::string& name, const std::string& value)
-    {
-      configs.push_back(tnt::ecppc::Variable(name, value));
-    }
+      { _configs.push_back(tnt::ecppc::Variable(name, value)); }
 
     void Generator::onScope(scope_container_type container, scope_type scope,
-      const std::string& type, const std::string& var, const std::string& init_)
+                            const std::string& type, const std::string& var,
+                            const std::string& init, const std::vector<std::string>& includes)
     {
-      log_debug("onScope type=\"" << type << "\" var=\"" << var << "\" init=\"" << init_ << '"');
-      tnt::ecppc::Component* comp = (scope == ecpp::page_scope ? &maincomp : currentComp);
+      log_debug("onScope type=\"" << type << "\" var=\"" << var << "\" init=\"" << init << '"');
+      tnt::ecppc::Component* comp = (scope == ecpp::page_scope ? &_maincomp : _currentComp);
 
-      comp->addScopevar(Scopevar(container, scope, type, var, init_, curline, curfile));
+      comp->addScopevar(Scopevar(container, scope, type, var, init, _curline, _curfile));
+
+      std::ostringstream m;
+      for (unsigned n = 0; n != includes.size(); ++n)
+        m << "#include <" << includes[n] << ">\n";
+      _pre += m.str();
     }
 
     void Generator::onInclude(const std::string& file)
-    {
-      currentComp->addHtml("  // <%include> " + file + '\n');
-    }
+      { _currentComp->addHtml("  // <%include> " + file + '\n'); }
 
-    void Generator::onIncludeEnd(const std::string& file)
-    {
-      currentComp->addHtml("  // </%include>\n");
-    }
-
-    void Generator::startI18n()
-    {
-      externData = true;
-    }
+    void Generator::onIncludeEnd(const std::string& /* file */)
+      { _currentComp->addHtml("  // </%include>\n"); }
 
     void Generator::getIntro(std::ostream& out, const std::string& filename) const
     {
@@ -326,9 +297,8 @@ namespace tnt
 
     void Generator::getHeaderIncludes(std::ostream& out) const
     {
-      if (multiImages.empty() && !isRawMode())
-        out << "#include <tnt/ecpp.h>\n"
-               "#include <tnt/convert.h>\n";
+      if (_multiImages.empty() && !isRawMode())
+        out << "#include <tnt/ecpp.h>\n";
       else
         out << "#include <tnt/mbcomponent.h>\n";
     }
@@ -336,17 +306,17 @@ namespace tnt
     void Generator::getPre(std::ostream& out) const
     {
       out << "// <%pre>\n"
-          << pre
+          << _pre
           << "// </%pre>\n";
     }
 
     void Generator::getClassDeclaration(std::ostream& out) const
     {
-      if (multiImages.empty() && !isRawMode())
+      if (_multiImages.empty() && !isRawMode())
       {
         out << "class _component_ : public tnt::EcppComponent\n"
                "{\n"
-               "    _component_& main()  { return *this; }\n\n" 
+               "    _component_& main()  { return *this; }\n\n"
                "  protected:\n"
                "    ~_component_();\n\n"
                "  public:\n"
@@ -358,36 +328,36 @@ namespace tnt
         out << "class _component_ : public tnt::MbComponent\n"
                "{\n"
                "    _component_& main()  { return *this; }\n\n" ;
-        if (compress)
-          out << "    tnt::DataChunks data;\n\n";
+        if (_compress)
+          out << "    tnt::DataChunks _tntChunks;\n\n";
         out << "  protected:\n"
                "    ~_component_();\n\n"
                "  public:\n"
                "    _component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl);\n\n";
       }
 
-      if (haveCloseComp)
+      if (_haveCloseComp)
         out << "    unsigned endTag(tnt::HttpRequest& request, tnt::HttpReply& reply,\n"
                "                    tnt::QueryParams& qparam);\n";
-      if (!attr.empty())
+      if (!_attr.empty())
         out << "    std::string getAttribute(const std::string& name,\n"
                "      const std::string& def = std::string()) const;\n\n";
 
-      if (!configs.empty())
+      if (!_configs.empty())
       {
-        out << "    // <%config>\n";
-        for (variable_declarations::const_iterator it = configs.begin();
-             it != configs.end(); ++it)
+        out << "    virtual void configure(const tnt::TntConfig& config);\n"
+               "    // <%config>\n";
+        for (variable_declarations::const_iterator it = _configs.begin(); it != _configs.end(); ++it)
           it->getConfigHDecl(out);
         out << "    // </%config>\n\n";
       }
 
       // declare subcomponents
-      for (subcomps_type::const_iterator i = subcomps.begin(); i != subcomps.end(); ++i)
+      for (subcomps_type::const_iterator i = _subcomps.begin(); i != _subcomps.end(); ++i)
         i->getHeader(out);
 
       // instantiate subcomponents
-      for (subcomps_type::const_iterator i = subcomps.begin(); i != subcomps.end(); ++i)
+      for (subcomps_type::const_iterator i = _subcomps.begin(); i != _subcomps.end(); ++i)
         out << "    " << i->getName() << "_type " << i->getName() << ";\n";
 
       out << "};\n\n";
@@ -402,11 +372,11 @@ namespace tnt
              "#include <tnt/data.h>\n"
              "#include <tnt/componentfactory.h>\n";
 
-      if (!configs.empty())
+      if (!_configs.empty())
         out << "#include <tnt/comploader.h>\n"
                "#include <tnt/tntconfig.h>\n";
 
-      if (compress)
+      if (_compress)
         out << "#include <tnt/zdata.h>\n";
 
       out << "#include <cxxtools/log.h>\n"
@@ -415,34 +385,25 @@ namespace tnt
 
     void Generator::getFactoryDeclaration(std::ostream& code) const
     {
-      if (configs.empty())
+      if (_configs.empty())
       {
-        code << "static tnt::ComponentFactoryImpl<_component_> Factory(\"" << maincomp.getName() << "\");\n\n";
+        code << "static tnt::EcppComponentFactoryImpl<_component_> Factory(\"" << _maincomp.getName() << "\");\n\n";
       }
       else
       {
-        code << "class _component_Factory : public tnt::ComponentFactoryImpl<_component_>\n"
+        code << "class _component_Factory : public tnt::EcppComponentFactoryImpl<_component_>\n"
                 "{\n"
                 "  public:\n"
                 "    _component_Factory()\n"
-                "      : tnt::ComponentFactoryImpl<_component_>(\"" << maincomp.getName() << "\")\n"
+                "      : tnt::EcppComponentFactoryImpl<_component_>(\"" << _maincomp.getName() << "\")\n"
                 "      { }\n"
                 "    tnt::Component* doCreate(const tnt::Compident& ci,\n"
                 "      const tnt::Urlmapper& um, tnt::Comploader& cl);\n"
-                "    virtual void doConfigure(const tnt::TntConfig& config);\n"
                 "};\n\n"
                 "tnt::Component* _component_Factory::doCreate(const tnt::Compident& ci,\n"
                 "  const tnt::Urlmapper& um, tnt::Comploader& cl)\n"
                 "{\n"
                 "  return new _component_(ci, um, cl);\n"
-                "}\n\n"
-                "void _component_Factory::doConfigure(const tnt::TntConfig& config)\n"
-                "{\n"
-                "  // <%config>\n";
-        for (variable_declarations::const_iterator it = configs.begin();
-             it != configs.end(); ++it)
-          it->getConfigInit(code);
-        code << "  // </%config>\n"
                 "}\n\n"
                 "static _component_Factory factory;\n\n";
       }
@@ -452,17 +413,17 @@ namespace tnt
     {
       getFactoryDeclaration(code);
 
-      if (!data.empty())
+      if (!_data.empty())
       {
-        if (compress)
+        if (_compress)
         {
           code << "static tnt::Zdata rawData(\n\"";
 
-          uLongf s = data.size() + data.size() / 100 + 100;
+          uLongf s = _data.size() + _data.size() / 100 + 100;
           std::vector<char> p(s);
           char* buffer = &p[0];
 
-          int z_ret = ::compress(reinterpret_cast<Bytef*>(buffer), &s, (const Bytef*)data.ptr(), data.size());
+          int z_ret = ::compress(reinterpret_cast<Bytef*>(buffer), &s, (const Bytef*)_data.ptr(), _data.size());
 
           if (z_ret != Z_OK)
           {
@@ -475,51 +436,49 @@ namespace tnt
           BStringPrinter bs(code, 2, 120, 30);
           bs.print(buffer, s);
 
-          code << "\",\n  " << s << ", " << data.size() << ");\n\n";
+          code << "\",\n  " << s << ", " << _data.size() << ");\n\n";
         }
         else
         {
           code << "static const char* rawData = \"";
 
           BStringPrinter bs(code, 2, 120, 30);
-          bs.print(data.ptr(), data.size());
+          bs.print(_data.ptr(), _data.size());
 
           code << "\";\n\n";
         }
       }
 
       // multi-images
-      if (!multiImages.empty())
+      if (!_multiImages.empty())
       {
         code << "static const char* urls[] = {\n";
 
-        for (MultiImagesType::const_iterator it = multiImages.begin();
-             it != multiImages.end(); ++it)
+        for (MultiImagesType::const_iterator it = _multiImages.begin(); it != _multiImages.end(); ++it)
           code << "  \"" << it->name << "\",\n";
 
         code << "};\n\n"
                 "static const char* mimetypes[] = {\n";
 
-        for (MultiImagesType::const_iterator it = multiImages.begin();
-             it != multiImages.end(); ++it)
+        for (MultiImagesType::const_iterator it = _multiImages.begin();
+             it != _multiImages.end(); ++it)
           code << "  \"" << it->mime << "\",\n";
 
         code << "};\n\n"
                 "const char* ctimes[] = {\n";
 
-        for (MultiImagesType::const_iterator it = multiImages.begin();
-             it != multiImages.end(); ++it)
+        for (MultiImagesType::const_iterator it = _multiImages.begin(); it != _multiImages.end(); ++it)
           code << "  \"" << tnt::HttpMessage::htdate(it->c_time) << "\",\n";
 
         code << "};\n\n";
 
-        if (compress)
+        if (_compress)
         {
           code << "_component_::_component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl)\n"
                   "  : MbComponent(ci, um, cl)\n"
                   "{\n"
                   "  ::rawData.addRef();\n"
-                  "  data.setData(::rawData);\n"
+                  "  _tntChunks.setData(::rawData);\n"
                   "  init(::rawData, ::urls, ::mimetypes, ::ctimes);\n"
                   "}\n\n"
                   "_component_::~_component_()\n"
@@ -538,16 +497,16 @@ namespace tnt
       }
       else if (isRawMode())
       {
-        code << "static const char* mimetype = \"" << mimetype << "\";\n"
-                "static const char* c_time = \"" << tnt::HttpMessage::htdate(c_time) << "\";\n\n";
+        code << "static const char* mimetype = \"" << _mimetype << "\";\n"
+                "static const char* c_time = \"" << tnt::HttpMessage::htdate(_c_time) << "\";\n\n";
 
-        if (compress)
+        if (_compress)
         {
           code << "_component_::_component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl)\n"
                   "  : MbComponent(ci, um, cl)\n"
                   "{\n"
                   "  ::rawData.addRef();\n"
-                  "  data.setData(::rawData);\n"
+                  "  _tntChunks.setData(::rawData);\n"
                   "  init(::rawData, ::mimetype, ::c_time);\n"
                   "}\n\n"
                   "_component_::~_component_()\n"
@@ -569,83 +528,86 @@ namespace tnt
         // logger, %shared and constructor
         //
         code << "// <%shared>\n"
-             << shared
+             << _shared
              << "// </%shared>\n\n";
         code << "// <%config>\n";
-        for (variable_declarations::const_iterator it = configs.begin();
-             it != configs.end(); ++it)
+        for (variable_declarations::const_iterator it = _configs.begin(); it != _configs.end(); ++it)
           it->getConfigDecl(code);
         code << "// </%config>\n\n"
-                "#define SET_LANG(lang) \\\n"
-                "     do \\\n"
-                "     { \\\n"
-                "       request.setLang(lang); \\\n"
-                "       reply.setLocale(request.getLocale()); \\\n";
-        if (externData)
-          code << "       data.setData(getData(request, rawData)); \\\n";
-        code << "     } while (false)\n\n"
              << "_component_::_component_(const tnt::Compident& ci, const tnt::Urlmapper& um, tnt::Comploader& cl)\n"
                 "  : EcppComponent(ci, um, cl)";
 
         // initialize subcomponents
-        for (subcomps_type::const_iterator i = subcomps.begin(); i != subcomps.end(); ++i)
+        for (subcomps_type::const_iterator i = _subcomps.begin(); i != _subcomps.end(); ++i)
           code << ",\n"
                   "    " << i->getName() << "(*this, \"" << i->getName() << "\")";
 
         code << "\n{\n";
 
-        if (compress)
+        if (_compress)
           code << "  rawData.addRef();\n";
 
         code << "  // <%init>\n"
-             << init
+             << _init
              << "  // </%init>\n"
                 "}\n\n"
                 "_component_::~_component_()\n"
                 "{\n"
                 "  // <%cleanup>\n"
-             << cleanup
+             << _cleanup
              << "  // </%cleanup>\n";
 
-        if (compress)
+        if (_compress)
           code << "  rawData.release();\n";
 
-        code << "}\n\n"
+        code << "}\n\n";
+
+        if (!_configs.empty())
+        {
+          code << "void _component_::configure(const tnt::TntConfig& config)\n"
+                  "{\n"
+                  "  // <%config>\n";
+          for (variable_declarations::const_iterator it = _configs.begin(); it != _configs.end(); ++it)
+            it->getConfigInit(code);
+          code << "  // </%config>\n"
+                  "}\n\n";
+        }
+
+        code << "template <typename T>\n"
+                "inline void _tnt_ignore_unused(const T&) { }\n\n"
+
                 "unsigned _component_::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam)\n"
-             << "{\n"
-                "  log_trace(\"" << maincomp.getName() << " \" << qparam.getUrl());\n\n";
+                "{\n"
+                "  log_trace(\"" << _maincomp.getName() << " \" << qparam.getUrl());\n\n";
 
-        if (raw)
+        if (_raw)
           code << "  reply.setKeepAliveHeader();\n\n";
-        if (!mimetype.empty())
-          code << "  reply.setContentType(\"" << mimetype << "\");\n";
+        if (!_mimetype.empty())
+          code << "  reply.setContentType(\"" << _mimetype << "\");\n";
 
-        if (c_time)
+        if (_c_time)
           code << "  {\n"
                   "    std::string s = request.getHeader(tnt::httpheader::ifModifiedSince);\n"
-                  "    if (s == \"" << tnt::HttpMessage::htdate(c_time) << "\")\n"
+                  "    if (s == \"" << tnt::HttpMessage::htdate(_c_time) << "\")\n"
                   "      return HTTP_NOT_MODIFIED;\n"
                   "  }\n";
 
-        if (!data.empty())
+        if (!_data.empty())
         {
-          if (externData)
-            code << "  tnt::DataChunks data(getData(request, rawData));\n";
-          else
-            code << "  tnt::DataChunks data(rawData);\n";
+          code << "  tnt::DataChunks _tntChunks(rawData);\n";
         }
 
-        if (multiImages.empty())
+        if (_multiImages.empty())
         {
-          if (c_time)
+          if (_c_time)
             code << "  reply.setHeader(tnt::httpheader::lastModified, \""
-                 << tnt::HttpMessage::htdate(c_time) << "\");\n";
-          if (raw)
-            code << "  reply.setContentLengthHeader(data.size(0));\n"
+                 << tnt::HttpMessage::htdate(_c_time) << "\");\n";
+          if (_raw)
+            code << "  reply.setContentLengthHeader(_tntChunks.size(0));\n"
                     "  reply.setDirectMode();\n";
 
           code << '\n';
-          maincomp.getBody(code, linenumbersEnabled);
+          _maincomp.getBody(code, _linenumbersEnabled);
           code << "}\n\n";
         }
         else
@@ -669,39 +631,37 @@ namespace tnt
                   "    return HTTP_NOT_MODIFIED;\n\n"
 
                   "  reply.setHeader(tnt::httpheader::lastModified, url_c_time[url_idx]);\n"
-                  "  reply.setContentLengthHeader(data.size(url_idx));\n"
+                  "  reply.setContentLengthHeader(_tntChunks.size(url_idx));\n"
                   "  reply.setDirectMode();\n"
-                  "  reply.out() << data[url_idx];\n"
-                  "  return HTTP_OK;\n"
+                  "  reply.out() << _tntChunks[url_idx];\n"
+                  "  return DEFAULT;\n"
                   "}\n\n";
         }
 
-        if (haveCloseComp)
-          closeComp.getDefinition(code, externData, linenumbersEnabled);
+        if (_haveCloseComp)
+          _closeComp.getDefinition(code, _linenumbersEnabled);
 
-        if (!attr.empty())
+        if (!_attr.empty())
         {
           code << "// <%attr>\n"
                   "std::string _component_::getAttribute(const std::string& name, const std::string& def) const\n"
                   "{\n";
-          for (attr_type::const_iterator it = attr.begin();
-               it != attr.end(); ++it)
+          for (attr_type::const_iterator it = _attr.begin(); it != _attr.end(); ++it)
             code << "  if (name == \"" << it->first << "\")\n"
                     "    return " << it->second << ";\n";
           code << "  return def;\n"
                   "} // </%attr>\n\n";
         }
 
-        for (subcomps_type::const_iterator i = subcomps.begin();
-             i != subcomps.end(); ++i)
-          i->getDefinition(code, externData, linenumbersEnabled);
+        for (subcomps_type::const_iterator it = _subcomps.begin(); it != _subcomps.end(); ++it)
+          it->getDefinition(code, _linenumbersEnabled);
       }
     }
 
     void Generator::printLine(std::ostream& out) const
     {
-      if (linenumbersEnabled)
-        out << "#line " << (curline + 1) << " \"" << curfile << "\"\n";
+      if (_linenumbersEnabled)
+        out << "#line " << (_curline + 1) << " \"" << _curfile << "\"\n";
     }
 
     void Generator::getCpp(std::ostream& code, const std::string& filename) const
@@ -711,12 +671,12 @@ namespace tnt
       getHeaderIncludes(code);
       getCppIncludes(code);
 
-      if (multiImages.empty() && !isRawMode())
-        code << "log_define(\"" << maincomp.getLogCategory() << "\")\n\n";
+      if (_multiImages.empty() && !isRawMode())
+        code << "log_define(\"" << _maincomp.getLogCategory() << "\")\n\n";
 
       getPre(code);
 
-      code << "\n" 
+      code << "\n"
               "namespace\n"
               "{\n";
 
@@ -728,3 +688,4 @@ namespace tnt
     }
   }
 }
+
