@@ -1,11 +1,11 @@
 /*
  * Copyright (C) 2005 Tommi Maekitalo
- * 
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * As a special exception, you may use this file as part of a free
  * software library without restriction. Specifically, if other files
  * instantiate templates or use macros or inline functions from this
@@ -15,12 +15,12 @@
  * License. This exception does not however invalidate any other
  * reasons why the executable file might be covered by the GNU Library
  * General Public License.
- * 
+ *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -43,30 +43,33 @@ namespace tnt
   {
     class Ecppc
     {
-        std::string requestname;
-        std::string extname;
-        const char* inputfile;
-
+      private:
         typedef std::map<std::string, std::string> inputfiles_type;
-        inputfiles_type inputfiles;
-
-        std::string ofile;
-        std::string odir;
-        std::string mimetype;
-        std::string mimedb;
-        std::string logCategory;
-        bool binary;
-        bool multibinary;
-        bool keepPath;
-        bool compress;
-        bool verbose;
-        bool generateDependencies;
-        bool disableLinenumbers;
-
         typedef std::list<std::string> includes_type;
-        includes_type includes;
 
-        int runDependencies();
+        std::string _componentname;
+        std::string _extname;
+        const char* _inputfile;
+
+        inputfiles_type _inputFiles;
+
+        std::string _ofile;
+        std::string _odir;
+        std::string _mimetype;
+        std::string _mimedb;
+        std::string _logCategory;
+        bool _binary;
+        bool _multibinary;
+        bool _keepPath;
+        bool _compress;
+        bool _verbose;
+        bool _generateDependencies;
+        bool _generateCMakeDependencies;
+        bool _disableLinenumbers;
+
+        includes_type _includes;
+
+        int runDependencies(bool cmake);
         int runGenerator();
         bool runParser(std::istream& in, tnt::ecpp::ParseHandler& handler, bool continueOnError);
 
@@ -74,19 +77,7 @@ namespace tnt
         Ecppc(int& argc, char* argv[]);
         int run();
     };
-
-    class Usage : public std::exception
-    {
-        std::string msg;
-      public:
-        Usage(const char* progname);
-        ~Usage() throw()  { }
-
-        const char* what() const throw()
-        { return msg.c_str(); }
-    };
   }
 }
 
 #endif // TNT_ECPPC_ECPPC_H
-
