@@ -39,16 +39,14 @@ namespace tnt
   {
     class Variable
     {
-        std::string name;
-        std::string type;
-        std::string value;
-        bool isvector;
-
-        void getParamCodeVector(std::ostream& o, const std::string& qparam) const;
+        std::string _name;
+        std::string _type;
+        std::string _value;
+        bool _isVector;
 
       public:
         Variable()  { }
-        Variable(const std::string& arg, const std::string& value_);
+        Variable(const std::string& arg, const std::string& value);
 
         void getParamCode(std::ostream& o, const std::string& qparam) const;
         void getConfigInit(std::ostream& o) const;
