@@ -35,7 +35,7 @@ namespace tnt
 {
   namespace ecppc
   {
-    Variable::Variable(const std::string& arg, const std::string& value_)
+    Variable::Variable(const std::string& arg, const std::string& value)
     {
       // 'name' might be prefixed by a type
       // the variablename is the last word in 'name'
@@ -44,8 +44,6 @@ namespace tnt
       //   " int var "
       //   " var"
       //   " ns :: someclass  param"
-      std::ostringstream a;
-
       std::string::size_type e = arg.size();
       while (e > 0 && std::isspace(arg.at(e - 1)))
         --e;
@@ -54,13 +52,13 @@ namespace tnt
 
       if (e > 1 && arg.at(e - 2) == '[' && arg.at(e-1) == ']')
       {
-        isvector = true;
+        _isVector = true;
         e -= 2;
         while (e > 0 && std::isspace(arg.at(e - 1)))
           --e;
       }
       else
-        isvector = false;
+        _isVector = false;
 
       std::string::size_type b = e;
       while (b > 0 && !std::isspace(arg.at(b - 1)))
@@ -72,90 +70,50 @@ namespace tnt
         --t;
       // t points past the last character of the type
 
-      name = std::string(arg.begin() + b, arg.begin() + e);
-      type = std::string(arg.begin(), arg.begin() + t);
-      value = value_;
+      _name = std::string(arg.begin() + b, arg.begin() + e);
+      _type = std::string(arg.begin(), arg.begin() + t);
+      _value = value;
 
     }
 
-    void Variable::getParamCodeVector(std::ostream& o, const std::string& qparam) const
-    {
-      if (type.empty())
-      {
-        o << "typedef std::vector<std::string> " << name << "_type;\n"
-          << name << "_type " << name << ";\n"
-          << "std::copy(" << qparam << ".begin(\"" << name
-          << "\"), " << qparam << ".end(), std::back_inserter(" << name
-          << "));\n";
-      }
-      else
-      {
-        o << "typedef std::vector<" << type << "> " << name << "_type;\n"
-          << name << "_type " << name << ";\n"
-          << "tnt::convertRange(\"" << name << "\", \"" << type
-          << "\", " << qparam << ".begin(\"" << name << "\"), " << qparam << ".end(), " << name
-          << ", reply.out().getloc());\n";
-      }
-    }
-
     void Variable::getParamCode(std::ostream& o, const std::string& qparam) const
     {
-      if (isvector)
-        getParamCodeVector(o, qparam);
-      else if (!type.empty())
+      std::string ltype = _type;
+      if (ltype.empty())
+        ltype = "std::string";
+
+      if (_isVector)
       {
-        // we have a type
-
-        // print out type and name
-        o << type << ' ' << name << " = ";
-
-        if (value.empty())
-        {
-          // no default-value
-
-          o << "tnt::stringTo<" << type
-            << ">(\"" << name << "\", \"" << type << "\", " << qparam << ".param(\"" << name << "\"), reply.out().getloc());\n";
-        }
-        else
-        {
-          // with default-value
-          o << qparam << ".has(\"" << name << "\") ? tnt::stringToWithDefault<" << type
-            << ">(" << qparam << ".param(\"" << name << "\"), (" << value << "), reply.out().getloc()) : ("
-            << value << ");\n";
-        }
+        o << "std::vector< " << ltype << " > " << _name << " = " << qparam << ".getvector< " << ltype << " >(\"" << _name << "\");\n";
+      }
+      else if (_value.empty())
+      {
+        o << ltype << ' ' << _name << " = " << qparam << ".get< " << ltype << " >(\"" << _name << "\");\n";
       }
       else
       {
-        // type defaults to std::string
-        o << "std::string " << name 
-          << " = " << qparam << ".param(\"" << name << '"';
-        if (!value.empty())
-          o << ", (" << value << ')';
-
-        o << ");\n";
+        o << ltype << ' ' << _name << " = " << qparam << ".get< " << ltype << " >(\"" << _name << "\", (" << _value << "));\n";
       }
     }
 
     void Variable::getConfigInit(std::ostream& o) const
-    {
-      o << "  config.config.getMember(\"" << name << "\", _component_::" << name << ");\n";
-    }
+      { o << "  config.config.getMember(\"" << _name << "\", _component_::" << _name << ");\n"; }
 
     void Variable::getConfigDecl(std::ostream& o) const
     {
-      std::string t = type.empty() ? "std::string" : type;
+      std::string t = _type.empty() ? "std::string" : _type;
 
-      o << t << " _component_::" << name;
-      if (!value.empty())
-        o << " = " << value;
+      o << t << " _component_::" << _name;
+      if (!_value.empty())
+        o << " = " << _value;
       o << ";\n";
     }
 
     void Variable::getConfigHDecl(std::ostream& o) const
     {
-      std::string t = type.empty() ? "std::string" : type;
+      std::string t = _type.empty() ? "std::string" : _type;
 
-      o << "    static " << t << " " << name << ";\n";
+      o << "    static " << t << " " << _name << ";\n";
     }
   }
 }
